@@ -225,7 +225,7 @@ sub displayIntroduction() {
     print("opportunity to make a lot of choices, but you don't have to.  " .
           "If \n");
     print("you don't have reason to believe you're smarter than Configure,\n");
-    print("Just take the defaults (hit ENTER) and don't sweat it.\n");
+    print("just take the defaults (hit ENTER) and don't sweat it.\n");
     print("\n");
 
     print("If you are considering having a program feed answers to the " .
@@ -689,8 +689,13 @@ sub inttypesDefault() {
 
         my $works;
 
-        my @candidateList = ("<inttypes.h>", "<types.h>", 
-                             "<sys/inttypes.h>", "<sys/types.h>");
+        # We have a report (2005.09.17) that on IRIX 5.3 with the
+        # native IDO cc, inttypes.h and sys/types.h conflict (and
+        # Netpbm program include sys/types for otherthings), so we
+        # prefer sys/types.h to inttypes.h here.
+
+        my @candidateList = ("<types.h>", "<sys/types.h>",
+                             "<inttypes.h>", "<sys/inttypes.h>");
         
         for (my $i = 0; $i < @candidateList && !$works; ++$i) {
             my $candidate = $candidateList[$i];
