@@ -23,8 +23,8 @@
   If you specify the option "-runtime", the output includes a -R
   option in addition, for every library after "-runtime" in the
   arguments.  -R tells the buildtime linker to include the specified
-  library in the search path that the runtime linker uses to find
-  dynamically linked libraries.
+  library's directory in the search path that the runtime linker uses
+  to find dynamically linked libraries.
 
   But if you compile this program with the EXPLICIT macro defined, and
   a library filepath contains a slash, then it skips all that -L/-l
@@ -453,6 +453,8 @@ processOneLibrary(const char *  const filepath,
    linker option string as a newly malloced null-terminated string at
    *optionsP.
 -----------------------------------------------------------------------------*/
+    unsigned int const MAX_OPT_SIZE = 1024;
+
     const char *directory;
         /* Directory component of 'filepath' */
     const char *filename;
@@ -506,18 +508,22 @@ main(int argc, char **argv) {
         if (strcmp(argv[arg], "-runtime") == 0)
             runtime = TRUE;
         else {
-            const char * options;
-            processOneLibrary(argv[arg], runtime, explicit, 
-                              &options, &error);
-            if (!error) {
-                if (strlen(outputLine) + strlen(options) + 1 + 1 > 
-                    sizeof(outputLine))
-                    error = TRUE;
-                else {
-                    strcat(outputLine, " ");
-                    strcat(outputLine, options);
+            if (strlen(argv[arg]) > 200)
+                error = TRUE;
+            else {
+                const char * options;
+                processOneLibrary(argv[arg], runtime, explicit, 
+                                  &options, &error);
+                if (!error) {
+                    if (strlen(outputLine) + strlen(options) + 1 + 1 > 
+                        sizeof(outputLine))
+                        error = TRUE;
+                    else {
+                        strcat(outputLine, " ");
+                        strcat(outputLine, options);
+                    }
+                    strfree(options);
                 }
-                strfree(options);
             }
         }
     }
