@@ -25,6 +25,7 @@
 #include "pnm.h"
 #include "shhopt.h"
 #include "bitio.h"
+#include "nstring.h"
 #include "bmp.h"
 
 /* MAXCOLORS is the maximum size of a color map in a BMP image */
@@ -100,7 +101,7 @@ struct cmdline_info {
     int verbose;    /* -verbose option */
 };
 
-static const char *ifname;
+static const char * ifname;
 
 
 
@@ -221,7 +222,7 @@ readOffBytes(FILE * const fp, unsigned int const nbytes) {
 
 
 static void
-BMPreadfileheader(FILE * const ifP, 
+BMPreadfileheader(FILE *         const ifP, 
                   unsigned int * const bytesReadP, 
                   unsigned int * const offBitsP) {
 
@@ -231,9 +232,11 @@ BMPreadfileheader(FILE * const ifP,
     unsigned long   offBits;
 
     if (GetByte(ifP) != 'B')
-        pm_error("%s is not a BMP file", ifname);
+        pm_error("'%s' is not a BMP file.  (It doesn't start with 'BM')",
+                 ifname);
     if (GetByte(ifP) != 'M')
-        pm_error("%s is not a BMP file", ifname);
+        pm_error("'%s' is not a BMP file.  (It doesn't start with 'BM')",
+                 ifname);
 
     cbSize = GetLong(ifP);
     xHotSpot = GetShort(ifP);
@@ -540,12 +543,22 @@ BMPreadinfoheader(FILE *                 const ifP,
 
 static void
 BMPreadcolormap(FILE *         const ifP, 
-                unsigned int   const cBitCount, 
                 int            const class, 
                 xel **         const colormapP, 
                 int            const cmapsize,
                 unsigned int * const bytesReadP) {
+/*----------------------------------------------------------------------------
+   Read the color map from the present position in the input BMP file
+   *ifP.
 
+   The map has 'cmapsize' entries in it.  cmapsize == 0 means there is
+   no color map.
+
+   We return a color map as *colormapP.  If there is no color map in the
+   BMP, this is just an arbitrary color map.
+
+   'class' is the class of BMP image - Windows or OS/2.
+-----------------------------------------------------------------------------*/
     int i;
 
     xel * colormap;
@@ -598,15 +611,11 @@ extractBitFields(unsigned int       const rasterval,
     unsigned int const abits = 
         (rasterval >> pixelformat.trn.shift) & pixelformat.trn.mask;
     
-    *rP = pixelformat.red.mask ?
-              (unsigned int) rbits * maxval / pixelformat.red.mask : 0;
-    *gP = pixelformat.grn.mask ?
-              (unsigned int) gbits * maxval / pixelformat.grn.mask : 0;
-    *bP = pixelformat.blu.mask ?
-              (unsigned int) bbits * maxval / pixelformat.blu.mask : 0;
-    *aP = pixelformat.trn.mask ?
-              (unsigned int) abits * maxval / pixelformat.trn.mask : 0;
-}
+    *rP = (unsigned int) rbits * maxval / pixelformat.red.mask;
+    *gP = (unsigned int) gbits * maxval / pixelformat.blu.mask;
+    *bP = (unsigned int) bbits * maxval / pixelformat.grn.mask;
+    *aP = (unsigned int) abits * maxval / pixelformat.trn.mask;
+}        
 
 
 
@@ -961,8 +970,8 @@ readBmp(FILE *               const ifP,
     if (verbose) 
         reportHeader(BMPheader, offBits);
 
-    if(offBits != BMPoffbits(BMPheader.class, BMPheader.cBitCount, 
-                             BMPheader.cmapsize)) {
+    if (offBits != BMPoffbits(BMPheader.class, BMPheader.cBitCount, 
+                              BMPheader.cmapsize)) {
         pm_message("warning: the BMP header says the raster starts "
                    "at offset %u bytes into the file (offbits), "
                    "but that there are %u bytes of information before "
@@ -974,15 +983,15 @@ readBmp(FILE *               const ifP,
     }
     {
         unsigned int bytesRead;
-        BMPreadcolormap(ifP, BMPheader.cBitCount, BMPheader.class, 
+        BMPreadcolormap(ifP, BMPheader.class, 
                         &colormap, BMPheader.cmapsize, &bytesRead);
         pos += bytesRead;
         if (bytesRead != BMPlencolormap(BMPheader.class, BMPheader.cBitCount, 
                                         BMPheader.cmapsize)) {
-            pm_message("warning: %u-byte RGB table, expected %u bytes"
-                       , bytesRead
-                   , BMPlencolormap(BMPheader.class, BMPheader.cBitCount, 
-                                    BMPheader.cmapsize));
+            pm_message("warning: %u-byte RGB table, expected %u bytes",
+                       bytesRead,
+                       BMPlencolormap(BMPheader.class, BMPheader.cBitCount, 
+                                      BMPheader.cmapsize));
         }
     }
 
@@ -1002,17 +1011,17 @@ readBmp(FILE *               const ifP,
     }
     if(pos != BMPlenfile(BMPheader.class, BMPheader.cBitCount, 
                          BMPheader.cmapsize, BMPheader.cols, BMPheader.rows)) {
-        pm_message("warning: read %u bytes, expected to read %u bytes"
-                   , pos
-                   , BMPlenfile(BMPheader.class, BMPheader.cBitCount, 
-                                BMPheader.cmapsize, 
-                                BMPheader.cols, BMPheader.rows));
+        pm_message("warning: read %u bytes, expected to read %u bytes",
+                   pos,
+                   BMPlenfile(BMPheader.class, BMPheader.cBitCount, 
+                              BMPheader.cmapsize, 
+                              BMPheader.cols, BMPheader.rows));
     }
-    *colsP = BMPheader.cols;
-    *rowsP = BMPheader.rows;
-    *cBitCountP = BMPheader.cBitCount;
+    *colsP        = BMPheader.cols;
+    *rowsP        = BMPheader.rows;
+    *cBitCountP   = BMPheader.cBitCount;
     *pixelformatP = BMPheader.pixelformat;
-    *colormapP = colormap;
+    *colormapP    = colormap;
 }
 
 
@@ -1074,9 +1083,9 @@ main(int argc, char ** argv) {
         /* Number of bits in BMP raster for each pixel */
     struct pixelformat pixelformat;
         /* Format of the raster bits for a single pixel */
-    xel *colormap;
-        /* Malloc'ed colormap (palette) from the BMP.  Undefined if
-           not a colormapped BMP.
+    xel * colormap;
+        /* Malloc'ed colormap (palette) from the BMP.  Contents of map
+           undefined if not a colormapped BMP.
         */
 
     pnm_init(&argc, argv);
@@ -1084,7 +1093,7 @@ main(int argc, char ** argv) {
     parse_command_line(argc, argv, &cmdline);
 
     ifP = pm_openr(cmdline.input_filespec);
-    if (strcmp(cmdline.input_filespec, "-"))
+    if (STREQ(cmdline.input_filespec, "-"))
         ifname = "Standard Input";
     else 
         ifname = cmdline.input_filespec;
@@ -1112,5 +1121,5 @@ main(int argc, char ** argv) {
     free(colormap);
     free(BMPraster);
 
-    exit(0);
+    return 0;
 }
