@@ -4,7 +4,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
-#include <netinet/in.h>
+#include <sys/types.h>
+#include <netinet/in.h>  /* for htonl(), ntohs() */
 
 #ifdef HAVE_JPEG
 #include <jpeglib.h>
@@ -826,7 +827,7 @@ kodak_dc120_load_raw()
 }
 
 void
-kodak_dc20_coeff (float juice)
+kodak_dc20_coeff (float const juice)
 {
   static const float my_coeff[3][4] =
   { {  2.25,  0.75, -1.75, -0.25 },
