@@ -23,11 +23,11 @@
  **
  ** Modified by Alberto Accomazzi (alberto@cfa.harvard.edu), Dec 1, 1992.
  **
- ** Added support for 3-planes FITS files, the program is renamed fitstopnm.
- ** Fixed some non-ansi declarations (DBL_MAX and FLT_MAX replace MAXDOUBLE
- ** and MAXFLOAT), fixed some scaling parameters to map the full FITS data
- ** resolution to the maximum PNM resolution, disabled min max scanning when
- ** reading from stdin.
+ ** Added understanding of 3-plane FITS files, the program is renamed
+ ** fitstopnm.  Fixed some non-ansi declarations (DBL_MAX and FLT_MAX
+ ** replace MAXDOUBLE and MAXFLOAT), fixed some scaling parameters to
+ ** map the full FITS data resolution to the maximum PNM resolution,
+ ** disabled min max scanning when reading from stdin.
  */
 
 #include <string.h>
@@ -416,7 +416,6 @@ read_val (fp, bitpix, vp)
         else
             lval = c[0]<<24 | c[1]<<16 | c[2]<<8 | c[3];
         *vp = lval;
-        break;
       
     case -32:
         for (i=0; i<4; i++) {
