@@ -363,37 +363,37 @@ static void getDiskObject( IconInfo *infoP ) {
  *-------------------------------------------------------------------------
  * Get fields from icon header portion of info file
  *-------------------------------------------------------------------------*/
-static void getIconHeader( IconInfo *infoP ) {
-  IconHeader  ihead;      /* Icon header structure */
-  int         iheadSize,  /* Icon header structure size */
-              rc;         /* Return code from fread() */
+static void 
+getIconHeader( IconInfo * const infoP ) {
+    IconHeader  ihead;      /* Icon header structure */
+    int         iheadSize,  /* Icon header structure size */
+        rc;         /* Return code from fread() */
 
-  /* Read icon header */
-  iheadSize = sizeof( ihead );
-  if ( ( rc = fread( &ihead, sizeof( char ), iheadSize, infoP->fp ) ) < 0 ) {
-    pm_close( infoP->fp );
-    pm_error( "Cannot read icon header for file %s: %s\n",
-      infoP->name, strerror( errno ) );
-  }
-  if ( rc != iheadSize  ) {
-    pm_close( infoP->fp );
-    pm_error( "Cannot read the entire icon header for file %s\n"
-      "Only read 0x%X of 0x%X bytes\n", infoP->name, rc, iheadSize  );
-  }
+    /* Read icon header */
+    iheadSize = sizeof( ihead );
+    if ( ( rc = fread( &ihead, sizeof( char ), iheadSize, infoP->fp ) ) < 0 ) {
+        pm_close( infoP->fp );
+        pm_error( "Cannot read icon header for file %s: %s\n",
+                  infoP->name, strerror( errno ) );
+    }
+    if ( rc != iheadSize  ) {
+        pm_close( infoP->fp );
+        pm_error( "Cannot read the entire icon header for file %s\n"
+                  "Only read 0x%X of 0x%X bytes\n",
+                  infoP->name, rc, iheadSize  );
+    }
 
-  /* Get icon width, heigh, and bitplanes */
-  infoP->width  = ( ihead.iconWidth[0]  << 8 ) + ihead.iconWidth[1];
-  infoP->height = ( ihead.iconHeight[0] << 8 ) + ihead.iconHeight[1];
-  infoP->depth  = ( ihead.bpp[0]        << 8 ) + ihead.bpp[1];
+    /* Get icon width, heigh, and bitplanes */
+    infoP->width  = ( ihead.iconWidth[0]  << 8 ) + ihead.iconWidth[1];
+    infoP->height = ( ihead.iconHeight[0] << 8 ) + ihead.iconHeight[1];
+    infoP->depth  = ( ihead.bpp[0]        << 8 ) + ihead.bpp[1];
 
-  /* Check number of bit planes */
-  if ( ( infoP->depth > 2 ) || ( infoP->depth < 1 ) ) {
-    pm_close( infoP->fp );
-    pm_error( "%d bitplanes is not supported in file %s\n"
-      "Only 1 or 2 bitplanes are supported!  Please send this file to\n"
-      "griswold@acm.org so I can add support for higher color icons!\n",
-      infoP->depth, infoP->name );
-  }
+    /* Check number of bit planes */
+    if ( ( infoP->depth > 2 ) || ( infoP->depth < 1 ) ) {
+        pm_close( infoP->fp );
+        pm_error( "We don't know how to interpret %d bitplanes file %s.  ",
+                  infoP->depth, infoP->name );
+    }
 }
 
 /*---------------
