@@ -1,3 +1,6 @@
+#ifndef JPEGDATASOURCE_H_INCLUDED
+#define JPEGDATASOURCE_H_INCLUDED
+
 struct sourceManager * 
 dsCreateSource(const char * const fileName);
 
@@ -9,3 +12,5 @@ dsDataLeft(struct sourceManager * const srcP);
 
 struct jpeg_source_mgr *
 dsJpegSourceMgr(struct sourceManager * const srcP);
+
+#endif
