@@ -93,15 +93,6 @@ typedef struct pngcolor {
     png_uint_16 b;
 } pngcolor;
 
-/* function prototypes */
-#ifdef __STDC__
-static png_uint_16 _get_png_val (png_byte **pp, int bit_depth);
-static int iscolor (png_color c);
-static void save_text (png_info *info_ptr, FILE *tfp);
-static void show_time (png_info *info_ptr);
-static void pngtopnm_error_handler (png_structp png_ptr, png_const_charp msg);
-int main (int argc, char *argv[]);
-#endif
 
 static png_uint_16 maxval;
 static int verbose = FALSE;
@@ -333,15 +324,12 @@ png_const_charp msg;
    * regardless of whether _BSD_SOURCE or anything else has (or has not)
    * been defined. */
 
-  fprintf(stderr, "pnmtopng:  fatal libpng error: %s\n", msg);
-  fflush(stderr);
+  pm_message("fatal libpng error: %s", msg);
 
   jmpbuf_ptr = png_get_error_ptr(png_ptr);
-  if (jmpbuf_ptr == NULL) {         /* we are completely hosed now */
-    fprintf(stderr,
-      "pnmtopng:  EXTREMELY fatal error: jmpbuf unrecoverable; terminating.\n");
-    fflush(stderr);
-    exit(99);
+  if (jmpbuf_ptr == NULL) {
+      /* we are completely hosed now */
+      pm_error("EXTREMELY fatal error: jmpbuf unrecoverable; terminating.");
   }
 
   longjmp(jmpbuf_ptr->jmpbuf, 1);
