@@ -2,30 +2,37 @@
 */
 
 #include "pnm.h"
+#include "mallocvar.h"
 
 #include "palm.h"
 
-int palmcolor_compare_indices (const void *p1, const void *p2)
-{
-  if ((*((Color) p1) & 0xFF000000) < (*((Color) p2) & 0xFF000000))
-    return -1;
-  else if ((*((Color) p1) & 0xFF000000) > (*((Color) p2) & 0xFF000000))
-    return 1;
-  else
-    return 0;
+int
+palmcolor_compare_indices(const void * const p1,
+                          const void * const p2) {
+
+    if ((*((Color) p1) & 0xFF000000) < (*((Color) p2) & 0xFF000000))
+        return -1;
+    else if ((*((Color) p1) & 0xFF000000) > (*((Color) p2) & 0xFF000000))
+        return 1;
+    else
+        return 0;
 }
 
-int palmcolor_compare_colors (const void *p1, const void *p2)
-{
-  register unsigned long val1 = *((const unsigned long *) p1) & 0xFFFFFF;
-  register unsigned long val2 = *((const unsigned long *) p2) & 0xFFFFFF;
 
-  if (val1 < val2)
-    return -1;
-  else if (val1 > val2)
-    return 1;
-  else
-    return 0;
+
+int
+palmcolor_compare_colors(const void * const p1,
+                         const void * const p2) {
+
+    unsigned long const val1 = *((const unsigned long *) p1) & 0xFFFFFF;
+    unsigned long const val2 = *((const unsigned long *) p2) & 0xFFFFFF;
+
+    if (val1 < val2)
+        return -1;
+    else if (val1 > val2)
+        return 1;
+    else
+        return 0;
 }
 
 /***********************************************************************
@@ -151,99 +158,119 @@ static int PalmPalette8bpp[256][3] =
   {   0,   0,   0 }, {   0,   0,   0 }, {   0,   0,   0 }, {   0,   0,   0 }
 };
 
-Colormap
-palmcolor_build_default_8bit_colormap(void)
-{
-  unsigned int i;
 
-  Colormap cm = malloc(sizeof(Colormap_s));
-  cm->color_entries = malloc(sizeof(Color_s) * 232);
-  cm->nentries = 232;
-  cm->ncolors = 232;
-  /* now fill in the colors */
-  for (i = 0; i < 231; i++) {
-    cm->color_entries[i] = ((i << 24) |
-			    (PalmPalette8bpp[i][0] << 16) |
-			    (PalmPalette8bpp[i][1] << 8) |
-			    (PalmPalette8bpp[i][2]));
-  }
-  cm->color_entries[231] = 0xFF000000;
-
-  /* now sort the table */
-  qsort (cm->color_entries, cm->ncolors, sizeof(Color_s), 
-         palmcolor_compare_colors);
-  return cm;
-}
 
 Colormap
-palmcolor_build_custom_8bit_colormap (unsigned int rows, unsigned int cols,
-                                      pixel **pixels)
-{
-  unsigned int row;
-  register unsigned int col;
-  register pixel *pP;
-  Color_s temp;
-  Color found;
-  Colormap colormap;
+palmcolor_build_default_8bit_colormap(void) {
 
-  colormap = malloc(sizeof(Colormap_s));
-  colormap->color_entries = malloc(sizeof(Color_s) * 256);
-  colormap->nentries = 256;
-  colormap->ncolors = 0;
+    unsigned int i;
 
-  for ( row = 0; row < rows; ++row ) {
-    for ( col = 0, pP = pixels[row]; col < cols; ++col, ++pP ) {
-      temp = ((PPM_GETR(*pP) << 16) |
-	      (PPM_GETG(*pP) << 8) |
-	      PPM_GETB(*pP));
-      found = (bsearch (&temp,
-			colormap->color_entries, colormap->ncolors,
-			sizeof(Color_s), palmcolor_compare_colors));
-      if (!found) {
-	/* add the new color, and re-sort */
-	if (colormap->nentries <= colormap->ncolors)
-	  pm_error("Too many colors for custom colormap (max 256).  "
-		   "Try using pnmquant to reduce the number of colors.");
-	else {
-	  temp |= ((colormap->ncolors) << 24);
-	  colormap->color_entries[colormap->ncolors] = temp;
-	  colormap->ncolors += 1;
-	  qsort (colormap->color_entries, colormap->ncolors, sizeof(Color_s), 
-             palmcolor_compare_colors);
-	  if (colormap->ncolors == 256)
-	    return colormap;
-	}
-      }
+    Colormap cm;
+
+    MALLOCVAR_NOFAIL(cm);
+    cm->nentries = 232;
+    MALLOCARRAY_NOFAIL(cm->color_entries, cm->nentries);
+
+    /* Fill in the colors */
+    for (i = 0; i < 231; ++i) {
+        cm->color_entries[i] = ((i << 24) |
+                                (PalmPalette8bpp[i][0] << 16) |
+                                (PalmPalette8bpp[i][1] << 8) |
+                                (PalmPalette8bpp[i][2]));
     }
-  }
+    cm->color_entries[231] = 0xFF000000;
+    cm->ncolors = 232;
 
-  return colormap;
+    /* now sort the table */
+    qsort (cm->color_entries, cm->ncolors, sizeof(Color_s), 
+           palmcolor_compare_colors);
+    return cm;
 }
 
+
+
 Colormap
-  palmcolor_read_colormap (FILE *ifp)
-{
-  unsigned int i;
-  long colorentry;
-  unsigned short ncolors;
-  Colormap colormap;
+palmcolor_build_custom_8bit_colormap(unsigned int const rows,
+                                     unsigned int const cols,
+                                     pixel **     const pixels) {
+    unsigned int row;
+    Colormap colormap;
 
-  if (pm_readbigshort(ifp, (short *) &ncolors) != 0)
-    return 0;
+    MALLOCVAR_NOFAIL(colormap);
+    colormap->nentries = 256;
+    MALLOCARRAY_NOFAIL(colormap->color_entries, colormap->nentries);
+    colormap->ncolors = 0;  /* initial value */
+    
+    for (row = 0; row < rows; ++row) {
+        unsigned int col;
+        for (col = 0; col < cols; ++col) {
+            Color found;
+            Color_s temp;
 
-  colormap = malloc(sizeof(Colormap_s));
-  colormap->color_entries = malloc(sizeof(Color_s) * ncolors);
-  colormap->nentries = ncolors;
-  colormap->ncolors = ncolors;
-
-  for (i = 0;  i < ncolors;  i++) {
-    if (pm_readbiglong(ifp, &colorentry) != 0) {
-      free (colormap->color_entries);
-      free (colormap);
-      return 0;
+            temp = ((PPM_GETR(pixels[row][col]) << 16) |
+                    (PPM_GETG(pixels[row][col]) << 8) |
+                    PPM_GETB(pixels[row][col]));
+            found = (bsearch (&temp,
+                              colormap->color_entries, colormap->ncolors,
+                              sizeof(Color_s), palmcolor_compare_colors));
+            if (!found) {
+                if (colormap->ncolors >= colormap->nentries)
+                    pm_error("Too many colors for custom colormap "
+                             "(max 256).  "
+                             "Try using pnmquant to reduce the number "
+                             "of colors.");
+                else {
+                    /* add the new color, and re-sort */
+                    temp |= ((colormap->ncolors) << 24);
+                    colormap->color_entries[colormap->ncolors] = temp;
+                    colormap->ncolors += 1;
+                    qsort(colormap->color_entries, colormap->ncolors, 
+                          sizeof(Color_s), palmcolor_compare_colors);
+                }
+            }
+        }
     }
-    colormap->color_entries[i] = (colorentry & 0xFFFFFFFF);
-  }
+    return colormap;
+}
 
-  return colormap;
+
+
+Colormap
+palmcolor_read_colormap (FILE * const ifP) {
+
+    unsigned short ncolors;
+    Colormap retval;
+    int rc;
+    
+    rc = pm_readbigshort(ifP, (short *) &ncolors);
+    if (rc != 0)
+        retval = NULL;
+    else {
+        long colorentry;
+        Colormap colormap;
+        unsigned int i;
+        bool error;
+
+        MALLOCVAR_NOFAIL(colormap);
+        colormap->nentries = ncolors;
+        MALLOCARRAY_NOFAIL(colormap->color_entries, colormap->nentries);
+        
+        for (i = 0, error = FALSE;  i < ncolors && !error;  ++i) {
+            int rc;
+            rc = pm_readbiglong(ifP, &colorentry);
+            if (rc != 0)
+                error = TRUE;
+            else
+                colormap->color_entries[i] = (colorentry & 0xFFFFFFFF);
+        }
+        if (error) {
+            free (colormap->color_entries);
+            free (colormap);
+            retval = NULL;
+        } else {
+            colormap->ncolors = ncolors;
+            retval = colormap;
+        }
+    }
+    return retval;
 }
