@@ -33,7 +33,6 @@
 #define _XOPEN_SOURCE 500  /* Make sure strdup() is in string.h */
 
 #include <string.h>
-#include <libgen.h>
 #include <assert.h>
 #include "pam.h"
 #include "mallocvar.h"
@@ -985,6 +984,14 @@ selectPostscriptLevel(bool           const levelIsGiven,
         levelIsGiven ? levelGiven : UINT_MAX;
     unsigned int minPossibleLevel;
 
+    /* Until we know, later in this function, that we needs certain
+       features, we assume we can get by with classic Postscript Level 1:
+    */
+    minPossibleLevel = 1;
+
+    /* Now we increase 'minPossibleLevel' as we notice that each of
+       various features are required:
+    */
     if (color) {
         minPossibleLevel = MAX(minPossibleLevel, 2);
         if (2 > maxPermittedLevel)
@@ -1124,20 +1131,24 @@ basebasename(const char * const filespec) {
 /*----------------------------------------------------------------------------
     Return filename up to first period
 -----------------------------------------------------------------------------*/
-    char * filespec2;
+    char const dirsep = '/';
+    const char * const lastSlashPos = strrchr(filespec, dirsep);
+
     char * name;
-    char * dotPosition;
-    
-    filespec2 = strdup(filespec);
+    const char * filename;
 
-    name = strdup(basename(filespec2));
+    if (lastSlashPos)
+        filename = lastSlashPos + 1;
+    else
+        filename = filespec;
 
-    strfree(filespec2);
-
-    dotPosition = strchr(name, '.');
-    if (dotPosition)
-        *dotPosition = '\0';
+    name = strdup(filename);
+    if (name != NULL) {
+        char * const dotPosition = strchr(name, '.');
 
+        if (dotPosition)
+            *dotPosition = '\0';
+    }
     return name;
 }
 
@@ -1158,7 +1169,7 @@ main(int argc, char * argv[]) {
 
     ifp = pm_openr(cmdline.input_filespec);
 
-    if (strcmp(cmdline.input_filespec, "-") == 0 )
+    if (STREQ(cmdline.input_filespec, "-"))
         name = strdup("noname");
     else
         name = basebasename(cmdline.input_filespec);
