@@ -66,6 +66,7 @@ Software copyrights will soon need family trees... :-)
 #include <fcntl.h>
 #include <tiffio.h>
 
+#include "nstring.h"
 #include "pnm.h"
 
 /* first release after testing */
@@ -789,7 +790,7 @@ standardOpt( Conv *conv, Root *r, int *argn, int argc, char **argv ) {
   }
   /* handle the special case of -1 (no removal) */
   if ( oldn == *argn && pm_keymatch( argv[*argn], "-gammap", 7 ) &&
-       *argn + 1 < argc && ! strcmp( argv[*argn + 1], "-1" ) ) {
+       *argn + 1 < argc && STREQ(argv[*argn + 1], "-1") ) {
     p->remove = 0 ;
     *argn = (*argn) + 2 ;
   } 
