@@ -136,7 +136,7 @@ parseCommandLine(int argc, char ** argv,
         pm_error("Too many arguments.  The only argument accepted "
                  "is the input file name");
 
-    if (alpha_spec && strcmp(cmdlineP->alphaFilename, "-") == 0 )
+    if (alpha_spec && STREQ(cmdlineP->alphaFilename, "-"))
         cmdlineP->alphaStdout = 1;
     else 
         cmdlineP->alphaStdout = 0;
@@ -1017,7 +1017,7 @@ main(int argc, char * argv[]) {
 
     parseCommandLine(argc, argv, &cmdline);
 
-    if (strcmp(cmdline.inputFilename, "-") != 0) {
+    if (!STREQ(cmdline.inputFilename, "-")) {
         tif = TIFFOpen(cmdline.inputFilename, "r");
         if (tif == NULL)
             pm_error("error opening TIFF file %s", cmdline.inputFilename);
