@@ -27,6 +27,7 @@
 #include "x11wd.h"
 #include "shhopt.h"
 #include "mallocvar.h"
+#include "nstring.h"
 
 static struct cmdline_info {
     /* All the information the user supplied in the command line,
@@ -191,13 +192,13 @@ parseCommandLine(int argc, char ** argv,
     if (argc - 1 == 0)
         cmdlineP->input_filename = NULL;  /* he wants stdin */
     else if (argc - 1 == 1) {
-        if (strcmp(argv[1], "-") == 0)
+        if (STREQ(argv[1], "-"))
             cmdlineP->input_filename = NULL;  /* he wants stdin */
         else 
             cmdlineP->input_filename = strdup(argv[1]);
     } else 
         pm_error("Too many arguments.  The only argument accepted\n"
-                 "is the input file specificaton");
+                 "is the input file specification");
 }
 
 
@@ -1267,7 +1268,7 @@ main( int argc, char *argv[] ) {
     }
 
 
-/* 
+/*
    This used to be the way we parsed a direct/true color pixel.  I'm 
    keeping it here in case we find out some application needs it this way.
 
@@ -1279,24 +1280,23 @@ main( int argc, char *argv[] ) {
    doesn't match these hard-coded shift amounts, so we have replaced
    this whole switch thing.  -Bryan 00.03.01
 
-   switch ( bits_per_pixel )
-            {
+   switch (bits_per_pixel) {
                 
-            case 16:
-            PPM_ASSIGN( *xP,
-            ( ( ul & red_mask )   >> 0    ),
-            ( ( ul & green_mask ) >> 5  ),
-            ( ( ul & blue_mask )  >> 11) );
-            break;
+   case 16:
+       PPM_ASSIGN( *xP,
+                   ( ( ul & red_mask )   >> 0    ),
+                   ( ( ul & green_mask ) >> 5  ),
+                   ( ( ul & blue_mask )  >> 11) );
+       break;
 
-            case 24:
-            case 32:
-            PPM_ASSIGN( *xP, ( ( ul & 0xff0000 ) >> 16 ),
-            ( ( ul & 0xff00 ) >> 8 ),
-            ( ul & 0xff ) );
-            break;
+   case 24:
+   case 32:
+       PPM_ASSIGN( *xP, ( ( ul & 0xff0000 ) >> 16 ),
+                   ( ( ul & 0xff00 ) >> 8 ),
+                   ( ul & 0xff ) );
+       break;
 
-            default:
-            pm_error( "True/Direct only supports 16, 24, and 32 bits" );
-            }
+   default:
+       pm_error( "True/Direct is valid only with 16, 24, and 32 bits" );
+   }
 */
