@@ -171,7 +171,7 @@ pbmtopk_add_suffix(char * const name,
     char *slash = strrchr(name, '/');
     char *dot = strrchr(name, '.');
 
-    if ((dot && slash ? dot < slash : !dot) && strcmp(name, "-"))
+    if ((dot && slash ? dot < slash : !dot) && !STREQ(name, "-"))
         strcat(name, suffix);
 }
 
@@ -507,7 +507,7 @@ shipcharacter(void) {
     MALLOCARRAY(bitcounts, height * width);
     if (repeatptr == NULL || bitcounts == NULL)
         pm_error("out of memory while allocating bit counts");
-    zerorow = pbm_allocrow(width) ;      /* initialise plain rows */
+    zerorow = pbm_allocrow(width) ;      /* initialize plain rows */
     onesrow = pbm_allocrow(width) ;
     for (i = 0 ; i < width ; i++) {
         zerorow[i] = PBM_WHITE ;
