@@ -16,6 +16,7 @@
 #include <string.h>
 #include "pgm.h"
 #include "mallocvar.h"
+#include "nstring.h"
 
 static char gmap [128] = {
 /*00 nul-bel*/  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
@@ -64,7 +65,7 @@ main( argc, argv )
 
     if ( argv[argn][0] == '-' )
     {
-        if ( strcmp( argv[argn], "-d" ) == 0 )
+        if ( STREQ( argv[argn], "-d" ) )
         {
             if ( argc == argn + 1 )
                 pm_usage( usage );
@@ -156,5 +157,5 @@ main( argc, argv )
 
     pgm_writepgm( stdout, grays, cols, rows, maxval, 0 );
 
-    exit( 0 );
+    return 0;
 }
