@@ -19,7 +19,7 @@
 **  - colormap files
 **  - direct color
 **  04/Oct/93:
-**  - multipalette support (PCHG chunk)
+**  - multipalette capability (PCHG chunk)
 **  - options -ignore, -isham, -isehb and -adjustcolors
 **  22/May/94:
 **  - minor change: check first for 24 planes, then for HAM
@@ -31,7 +31,7 @@
 **  - major rework of colormap/multipalette handling
 **  - now uses numeric IFF IDs
 **  24/Oct/94:
-**  - transparentColor support
+**  - transparentColor capability
 **  - added RGBN/RGB8 image types
 **  - 24-bit & direct color modified to n-bit deep ILBM
 **  22/Feb/95:
@@ -52,6 +52,7 @@ typedef struct {
     int reg;            /* color register to change */
     pixval r, g, b;     /* new colors for register */
 } PaletteChange;
+
 typedef struct {
     pixel *color;
     int    ncolors;
@@ -68,6 +69,7 @@ typedef struct {
     int mp_flags;
     IFF_ID  mp_id;
 } ColorMap;
+
 #define HAS_COLORMAP(cmap)      ((cmap) && (cmap)->color)
 #define HAS_COLORLUT(cmap)      ((cmap) && ((cmap)->redlut || (cmap)->greenlut || (cmap)->bluelut))
 #define HAS_MONOLUT(cmap)       ((cmap) && (cmap)->monolut)
@@ -117,22 +119,29 @@ ID2string(id)
  Memory allocation
  ****************************************************************************/
 static ColorMap *
-alloc_cmap ARGS((void))
-{
-    ColorMap *cmap;
+alloc_cmap(void) {
+
+    ColorMap * cmap;
 
     MALLOCVAR_NOFAIL(cmap);
 
-    cmap->color = NULL;
-    cmap->ncolors = 0;
-    cmap->monolut = cmap->redlut = cmap->greenlut = cmap->bluelut = NULL;
-    cmap->mp_init = NULL;
+    cmap->color     = NULL;
+    cmap->ncolors   = 0;
+    cmap->monolut   = NULL;
+    cmap->redlut    = NULL;
+    cmap->greenlut  = NULL;
+    cmap->bluelut   = NULL;
+    cmap->mp_init   = NULL;
     cmap->mp_change = NULL;
-    cmap->mp_rows = cmap->mp_type = cmap->mp_flags = 0;
+    cmap->mp_rows   = 0;
+    cmap->mp_type   = 0;
+    cmap->mp_flags  = 0;
+
     return cmap;
 }
 
 
+
 static rawtype *
 alloc_rawrow(cols)
     int cols;
@@ -302,140 +311,126 @@ display_chunk(FILE *        const ifP,
 }
 
 
-static ColorMap *
-read_cmap(ifp, iffid, chunksize, cmap)
-    FILE *ifp;
-    IFF_ID iffid;
-    long chunksize;
-    ColorMap *cmap;
-{
-    int i, r, g, b;
+static void
+read_cmap(FILE *     const ifp,
+          IFF_ID     const iffid,
+          long       const chunksize,
+          ColorMap * const cmap) {
+
     long colors;
 
     colors = chunksize / 3;
     if( colors == 0 ) {
         pm_error("warning - empty %s colormap", ID2string(iffid));
         skip_chunk(ifp, iffid, chunksize);
-        return cmap;
+    } else {
+        unsigned int i;
+        if( cmap->color )               /* prefer CMAP-chunk over CMYK-chunk */
+            ppm_freerow(cmap->color);
+        cmap->color = ppm_allocrow(colors);
+        cmap->ncolors = colors;
+        
+        for( i = 0; i < colors; ++i ) {
+            int r, g, b;
+            r = get_byte(ifp, iffid, &chunksize);
+            g = get_byte(ifp, iffid, &chunksize);
+            b = get_byte(ifp, iffid, &chunksize);
+            PPM_ASSIGN(cmap->color[i], r, g, b);
+        }
+        chunk_end(ifp, iffid, chunksize);
     }
-
-    if( !cmap )
-        cmap = alloc_cmap();
-    else
-    if( cmap->color )               /* prefer CMAP-chunk over CMYK-chunk */
-        ppm_freerow(cmap->color);
-    cmap->color = ppm_allocrow(colors);
-    cmap->ncolors = colors;
-
-    for( i = 0; i < colors; i++ ) {
-        r = get_byte(ifp, iffid, &chunksize);
-        g = get_byte(ifp, iffid, &chunksize);
-        b = get_byte(ifp, iffid, &chunksize);
-        PPM_ASSIGN(cmap->color[i], r, g, b);
-    }
-    chunk_end(ifp, iffid, chunksize);
-    return cmap;
 }
 
 
-static ColorMap *
-read_cmyk(ifp, iffid, chunksize, cmap)
-    FILE *ifp;
-    IFF_ID iffid;
-    long chunksize;
-    ColorMap *cmap;
-{
-    long colors;
-    int i;
+
+static void
+read_cmyk(FILE *     const ifp,
+          IFF_ID     const iffid,
+          long       const chunksize,
+          ColorMap * const cmap) {
 
     if( HAS_COLORMAP(cmap) ) {      /* prefer RGB color map */
         skip_chunk(ifp, iffid, chunksize);
-        return cmap;
-    }
+    } else {
+        long const colors = chunksize/4;
+        if( colors == 0 ) {
+            pm_error("warning - empty %s colormap", ID2string(iffid));
+            skip_chunk(ifp, iffid, chunksize);
+        } else {
+            unsigned int i;
+            cmap->color = ppm_allocrow(colors);
+            cmap->ncolors = colors;
+            
+            for( i = 0; i < colors; ++i ) {
+                int c, m, y, k;
+                c = get_byte(ifp, iffid, &chunksize);
+                m = get_byte(ifp, iffid, &chunksize);
+                y = get_byte(ifp, iffid, &chunksize);
+                k = get_byte(ifp, iffid, &chunksize);
 
-    colors = chunksize/4;
-    if( colors == 0 ) {
-        pm_error("warning - empty %s colormap", ID2string(iffid));
-        skip_chunk(ifp, iffid, chunksize);
-        return cmap;
-    }
-    if( !cmap )
-        cmap = alloc_cmap();
-    cmap->color = ppm_allocrow(colors);
-    cmap->ncolors = colors;
+                {
+                    pixval const red = 
+                        MAXCOLVAL - MIN(MAXCOLVAL,
+                                        c*(MAXCOLVAL-k)/MAXCOLVAL+k); 
+                    pixval const green = 
+                        MAXCOLVAL - MIN(MAXCOLVAL,
+                                        m*(MAXCOLVAL-k)/MAXCOLVAL+k);
+                    pixval const blue = 
+                        MAXCOLVAL - MIN(MAXCOLVAL,
+                                        y*(MAXCOLVAL-k)/MAXCOLVAL+k);
 
-    for( i = 0; i <colors; i++ ) {
-        int c, m, y, k;
-        c = get_byte(ifp, iffid, &chunksize);
-        m = get_byte(ifp, iffid, &chunksize);
-        y = get_byte(ifp, iffid, &chunksize);
-        k = get_byte(ifp, iffid, &chunksize);
-
-        {
-            pixval const red = 
-                MAXCOLVAL - MIN(MAXCOLVAL, c*(MAXCOLVAL-k)/MAXCOLVAL+k); 
-            pixval const green = 
-                MAXCOLVAL - MIN(MAXCOLVAL, m*(MAXCOLVAL-k)/MAXCOLVAL+k);
-            pixval const blue = 
-                MAXCOLVAL - MIN(MAXCOLVAL, y*(MAXCOLVAL-k)/MAXCOLVAL+k);
-
-            PPM_ASSIGN(cmap->color[i], red, green, blue);
+                    PPM_ASSIGN(cmap->color[i], red, green, blue);
+                }
+            }
+            chunk_end(ifp, iffid, chunksize);
         }
     }
-    chunk_end(ifp, iffid, chunksize);
-    return cmap;
 }
 
 
-static ColorMap *
+
+static void
 read_clut(FILE *        const ifp,
           IFF_ID        const iffid,
           unsigned long const chunksize,
-          ColorMap *    const cmapArg) {
+          ColorMap *    const cmap) {
 
-    long type;
-    unsigned char *lut;
-    int i;
-    ColorMap * cmap;
-    unsigned long remainingChunksize;
-
-    if( chunksize != CLUTSize ) {
+    if (chunksize != CLUTSize) {
         pm_message("invalid size for %s chunk - skipping it", 
                    ID2string(iffid));
         skip_chunk(ifp, iffid, chunksize);
-        return cmap;
-    }
-    
-    if (cmapArg)
-        cmap = cmapArg;
-    else
-        cmap = alloc_cmap();
-        
-    type = get_big_long(ifp, iffid, &remainingChunksize);
-    get_big_long(ifp, iffid, &remainingChunksize);    /* skip reserved field */
+    } else {
+        long type;
+        unsigned char * lut;
+        unsigned long remainingChunksize;
+        unsigned int i;
 
-    MALLOCARRAY_NOFAIL(lut, 256);
-    for( i = 0; i < 256; i++ )
-        lut[i] = get_byte(ifp, iffid, &remainingChunksize);
+        type = get_big_long(ifp, iffid, &remainingChunksize);
+        get_big_long(ifp, iffid, &remainingChunksize); /* skip reserved fld */
 
-    switch( type ) {
+        MALLOCARRAY_NOFAIL(lut, 256);
+        for( i = 0; i < 256; ++i )
+            lut[i] = get_byte(ifp, iffid, &remainingChunksize);
+
+        switch( type ) {
         case CLUT_MONO:
-            cmap->monolut = lut;
+            cmap->monolut  = lut;
             break;
         case CLUT_RED:
-            cmap->redlut = lut;
+            cmap->redlut   = lut;
             break;
         case CLUT_GREEN:
             cmap->greenlut = lut;
             break;
         case CLUT_BLUE:
-            cmap->bluelut = lut;
+            cmap->bluelut  = lut;
             break;
         default:
-            pm_message("warning - %s type %ld not supported", ID2string(iffid), type);
+            pm_message("warning - %s type %ld not recognized",
+                       ID2string(iffid), type);
             free(lut);
+        }
     }
-    return cmap;
 }
 
 
@@ -497,7 +492,7 @@ read_bmhd(FILE *        const ifP,
                                    mskNAME[bmhdP->masking]);
                     break;
                 case mskLasso:
-                    pm_message("warning - masking type '%s' not supported", 
+                    pm_message("warning - masking type '%s' not recognized", 
                                mskNAME[bmhdP->masking]);
                     break;
                 default:
@@ -673,7 +668,7 @@ decode_mask(FILE *          const ifP,
         }
         break;
     case mskLasso:
-        /* not supported yet */
+        pm_error("This program does not know how to process Lasso masking");
         break;
     default:
         pm_error("decode_mask(): unknown masking type %d - can't happen", 
@@ -1281,8 +1276,9 @@ dcol_to_ppm(FILE *         const ifP,
         bmhdP->masking = mskNone;
     }
 
-    if( HAS_COLORLUT(cmap) ) {      /* TODO */
-        pm_error("%s chunk not supported in direct color", ID2string(ID_CLUT));
+    if( HAS_COLORLUT(cmap) ) {
+        pm_error("This program does not know how to process a %s chunk "
+                 "in direct color", ID2string(ID_CLUT));
         cmap->redlut = cmap->greenlut = cmap->bluelut = NULL;
     }
 
@@ -1379,7 +1375,7 @@ ipbm_to_ppm(FILE *         const ifP,
                  bmhdP->nPlanes);
 
     if( bmhdP->masking == mskHasMask )
-        pm_error("maskplane not supported in IFF-PBM");
+        pm_error("Image has a maskplane, which is invalid in IFF-PBM");
 
     if( HAS_COLORMAP(cmap) )
         maxval = MAXCOLVAL;
@@ -1569,58 +1565,55 @@ rgbn_to_ppm(FILE *         const ifP,
 
 
 
-static ColorMap *
+static void
 read_4bit_mp(FILE *     const ifP,
              IFF_ID     const iffid,
              long       const chunksize,
-             ColorMap * const cmapArg) {
+             ColorMap * const cmap) {
 
     int row, rows, i, type;
     short data;
-    ColorMap * cmap;
     unsigned long remainingChunksize;
 
-    if (cmapArg)
-        cmap = cmapArg;
-    else
-        cmap = alloc_cmap();
-
     type = (iffid == ID_SHAM ? MP_TYPE_SHAM : MP_TYPE_CTBL);
 
     if( cmap->mp_type >= type ) {
         skip_chunk(ifP, iffid, chunksize);
-        return cmap;
-    }
-    if( cmap->mp_type )
-        multi_free(cmap);
-    cmap->mp_type = type;
+    } else {
+        if( cmap->mp_type )
+            multi_free(cmap);
+        cmap->mp_type = type;
 
-    remainingChunksize = chunksize;  /* initial value */
+        remainingChunksize = chunksize;  /* initial value */
 
-    if( type == MP_TYPE_SHAM ) {
-        cmap->mp_flags = MP_FLAGS_SKIPLACED;
-        get_big_short(ifP, iffid, &remainingChunksize);   /* skip first word */
-    }
-
-    cmap->mp_rows = rows = remainingChunksize/32;    /* sizeof(word) * 16 */
-    MALLOCARRAY_NOFAIL(cmap->mp_change, rows);
-
-    for( row = 0; row < rows; row++ ) {
-        MALLOCARRAY_NOFAIL(cmap->mp_change[row], 17);   /* 16 + sentinel */
-        for( i = 0; i < 16; i++ ) {
-            data = get_big_short(ifP, iffid, &remainingChunksize);
-            cmap->mp_change[row][i].reg = i;
-            cmap->mp_change[row][i].r = ((data & 0x0f00) >> 8) * FACTOR_4BIT;
-            cmap->mp_change[row][i].g = ((data & 0x00f0) >> 4) * FACTOR_4BIT;
-            cmap->mp_change[row][i].b = ((data & 0x000f) >> 0) * FACTOR_4BIT;
+        if( type == MP_TYPE_SHAM ) {
+            cmap->mp_flags = MP_FLAGS_SKIPLACED;
+            get_big_short(ifP, iffid, &remainingChunksize); /* skip first wd */
         }
-        cmap->mp_change[row][16].reg = MP_REG_END;   /* sentinel */
+
+        cmap->mp_rows = rows = remainingChunksize/32; /* sizeof(word) * 16 */
+        MALLOCARRAY_NOFAIL(cmap->mp_change, rows);
+
+        for( row = 0; row < rows; row++ ) {
+            MALLOCARRAY_NOFAIL(cmap->mp_change[row], 17);   /* 16 + sentinel */
+            for( i = 0; i < 16; i++ ) {
+                data = get_big_short(ifP, iffid, &remainingChunksize);
+                cmap->mp_change[row][i].reg = i;
+                cmap->mp_change[row][i].r =
+                    ((data & 0x0f00) >> 8) * FACTOR_4BIT;
+                cmap->mp_change[row][i].g =
+                    ((data & 0x00f0) >> 4) * FACTOR_4BIT;
+                cmap->mp_change[row][i].b =
+                    ((data & 0x000f) >> 0) * FACTOR_4BIT;
+            }
+            cmap->mp_change[row][16].reg = MP_REG_END;   /* sentinel */
+        }
+        chunk_end(ifP, iffid, remainingChunksize);
     }
-    chunk_end(ifP, iffid, remainingChunksize);
-    return cmap;
 }
 
 
+
 static void
 PCHG_DecompHuff(src, dest, tree, origsize)
     unsigned char *src, *dest;
@@ -1889,18 +1882,11 @@ fail2:
 }
 
 
-static ColorMap *
+static void
 read_pchg(FILE *     const ifp,
           IFF_ID     const iffid,
           long       const chunksize,
-          ColorMap * const cmapArg) {
-
-    ColorMap * cmap;
-
-    if (cmapArg)
-        cmap = cmapArg;
-    else
-        cmap = alloc_cmap();
+          ColorMap * const cmap) {
 
     if( cmap->mp_type >= MP_TYPE_PCHG ) {
         skip_chunk(ifp, iffid, chunksize);
@@ -1969,7 +1955,8 @@ read_pchg(FILE *     const ifp,
         }
 
         if( PCHG.Flags & PCHGF_USE_ALPHA )
-            pm_message("warning - PCHG alpha channel not supported");
+            pm_message("warning - ignoring PCHG alpha channel because "
+                       "this program doesn't know what to do with it");
 
         cmap->mp_rows = PCHG.StartLine + PCHG.LineCount;
         MALLOCARRAY_NOFAIL(cmap->mp_change, cmap->mp_rows);
@@ -2005,13 +1992,10 @@ read_pchg(FILE *     const ifp,
         free(data);
         chunk_end(ifp, iffid, remainingChunksize);
     }
-    return cmap;
 }
 
 
 
-
-
 static bool
 ignored_iffid(IFF_ID       const iffid,
               IFF_ID       const ignorelist[],
@@ -2104,7 +2088,7 @@ process_chunk(FILE *          const ifp,
               bool *          const bodyChunkProcessedP,
               bool *          const endchunkP,
               BitMapHeader ** const bmhdP,
-              ColorMap **     const cmapP,
+              ColorMap *      const cmap,
               DirectColor **  const dcolP,
               int *           const viewportmodesP,
               long *          const bytesReadP
@@ -2128,7 +2112,7 @@ process_chunk(FILE *          const ifp,
         pm_message("ignoring %s chunk", ID2string(iffid));
         skip_chunk(ifp, iffid, chunksize);
     } else if( iffid == ID_END ) {
-        /* END chunks are not officially supported in IFF, but
+        /* END chunks are not officially valid in IFF, but
            suggested as a future expansion for stream-writing,
            see Amiga RKM Devices, 3rd Ed, page 376 
         */
@@ -2151,13 +2135,13 @@ process_chunk(FILE *          const ifp,
             *bmhdP = read_bmhd(ifp, iffid, chunksize);
             break;
         case ID_CMAP:
-            *cmapP = read_cmap(ifp, iffid, chunksize, *cmapP);
+            read_cmap(ifp, iffid, chunksize, cmap);
             break;
         case ID_CMYK:
-            *cmapP = read_cmyk(ifp, iffid, chunksize, *cmapP);
+            read_cmyk(ifp, iffid, chunksize, cmap);
             break;
         case ID_CLUT:
-            *cmapP = read_clut(ifp, iffid, chunksize, *cmapP);
+            read_clut(ifp, iffid, chunksize, cmap);
             break;
         case ID_CAMG:
             if( chunksize != CAMGChunkSize )
@@ -2166,11 +2150,11 @@ process_chunk(FILE *          const ifp,
             *viewportmodesP &= viewportmask;      /* -isnotham/-isnotehb */
             break;
         case ID_PCHG:
-            *cmapP = read_pchg(ifp, iffid, chunksize, *cmapP);
+            read_pchg(ifp, iffid, chunksize, cmap);
             break;
         case ID_CTBL:
         case ID_SHAM:
-            *cmapP = read_4bit_mp(ifp, iffid, chunksize, *cmapP);
+            read_4bit_mp(ifp, iffid, chunksize, cmap);
             break;
         case ID_DCOL:
             if( chunksize != DirectColorSize )
@@ -2187,7 +2171,7 @@ process_chunk(FILE *          const ifp,
                 return;
             }
     
-            process_body(ifp, chunksize, *bmhdP, *cmapP, 
+            process_body(ifp, chunksize, *bmhdP, cmap, 
                          maskfile, fakeviewport, isdeepopt, *dcolP,
                          viewportmodesP);
 
@@ -2247,7 +2231,7 @@ main(int argc, char *argv[]) {
     int viewportmodes = 0, fakeviewport = 0, viewportmask;
     IFF_ID firstIffid;
     BitMapHeader *bmhdP = NULL;
-    ColorMap *cmap = NULL;
+    ColorMap * cmap;
     DirectColor *dcol = NULL;
 #define MAX_IGNORE  16
     IFF_ID ignorelist[MAX_IGNORE];
@@ -2333,6 +2317,8 @@ main(int argc, char *argv[]) {
                   "type FORM IFF file" );
     bytesread = 4;  /* FORM and formsize do not count */
 
+    cmap = alloc_cmap();
+
     /* Main loop, parsing the IFF FORM. */
     bodyChunkProcessed = FALSE;
     endchunk = FALSE;
@@ -2343,7 +2329,7 @@ main(int argc, char *argv[]) {
                       fakeviewport, viewportmask,
                       isdeepopt, cmaponly,
                       &bodyChunkProcessed,
-                      &endchunk, &bmhdP, &cmap, &dcol,
+                      &endchunk, &bmhdP, cmap, &dcol,
                       &viewportmodes, &bytes_read_for_chunk);
 
         bytesread += bytes_read_for_chunk;
