@@ -73,7 +73,7 @@ struct pixMap {
     longword pmReserved;
 };
 
-struct RGBColour {
+struct RGBColor {
     word red;
     word green;
     word blue;
@@ -88,7 +88,7 @@ struct Pattern {
     byte pix[64];
 };
 
-typedef void (*transfer_func) (struct RGBColour* src, struct RGBColour* dst);
+typedef void (*transfer_func) (struct RGBColor* src, struct RGBColor* dst);
 
 static const char* stage;
 static struct Rect picFrame;
@@ -102,13 +102,13 @@ static int verbose;
 static int fullres;
 static int recognize_comment;
 
-static struct RGBColour black = { 0, 0, 0 };
-static struct RGBColour white = { 0xffff, 0xffff, 0xffff };
+static struct RGBColor black = { 0, 0, 0 };
+static struct RGBColor white = { 0xffff, 0xffff, 0xffff };
 
 /* various bits of drawing state */
-static struct RGBColour foreground = { 0, 0, 0 };
-static struct RGBColour background = { 0xffff, 0xffff, 0xffff };
-static struct RGBColour op_colour;
+static struct RGBColor foreground = { 0, 0, 0 };
+static struct RGBColor background = { 0xffff, 0xffff, 0xffff };
+static struct RGBColor op_color;
 static struct Pattern bkpat;
 static struct Pattern fillpat;
 static struct Rect clip_rect;
@@ -144,15 +144,15 @@ struct opdef {
 };
 
 struct blit_info {
-    struct Rect srcRect;
-    struct Rect srcBounds;
-    int     srcwid;
-    byte*       srcplane;
-    int     pixSize;
-    struct Rect dstRect;
-    struct RGBColour* colour_map;
-    int     mode;
-    struct blit_info* next;
+    struct Rect        srcRect;
+    struct Rect        srcBounds;
+    int                srcwid;
+    byte*              srcplane;
+    int                pixSize;
+    struct Rect        dstRect;
+    struct RGBColor *  color_map;
+    int                mode;
+    struct blit_info * next;
 };
 
 static struct blit_info* blit_list = 0;
@@ -175,7 +175,7 @@ static struct blit_info** last_bl = &blit_list;
 #define resf(skipfunction) \
 { "reserved", NA, (skipfunction), "reserved for Apple use" }
 
-/* seems like RGB colours are 6 bytes, but Apple says they're variable */
+/* seems like RGB colors are 6 bytes, but Apple says they're variable */
 /* I'll use 6 for now as I don't care that much. */
 #define RGB_LEN (6)
 
@@ -646,7 +646,7 @@ rectscale(struct Rect * const r,
 static struct blit_info* 
 add_blit_list(void) {
     struct blit_info* bi;
-
+    
     MALLOCVAR(bi);
     if (bi == NULL)
         pm_error("out of memory for blit list");
@@ -664,9 +664,9 @@ add_blit_list(void) {
  *
  * Note src[Not]{Or,Xor,Copy} only work if the source pixmap was originally
  * a bitmap.
- * There's also a small bug that the foreground and background colours
+ * There's also a small bug that the foreground and background colors
  * are not used in a srcCopy; this wouldn't be hard to fix.
- * It IS a problem since the foreground and background colours CAN be changed.
+ * It IS a problem since the foreground and background colors CAN be changed.
  */
 
 #define rgb_all_same(x, y) \
@@ -675,9 +675,10 @@ add_blit_list(void) {
 #define rgb_is_black(x) rgb_all_same((x), 0)
 
 static void 
-srcCopy(struct RGBColour * const src, 
-        struct RGBColour * const dst) {
-        if (rgb_is_black(src))
+srcCopy(struct RGBColor * const src, 
+        struct RGBColor * const dst) {
+
+    if (rgb_is_black(src))
         *dst = foreground;
     else
         *dst = background;
@@ -686,8 +687,8 @@ srcCopy(struct RGBColour * const src,
 
 
 static void 
-srcOr(struct RGBColour * const src, 
-      struct RGBColour * const dst) {
+srcOr(struct RGBColor * const src, 
+      struct RGBColor * const dst) {
     if (rgb_is_black(src))
         *dst = foreground;
 }
@@ -695,18 +696,18 @@ srcOr(struct RGBColour * const src,
 
 
 static void 
-srcXor(struct RGBColour * const src, 
-       struct RGBColour * const dst) {
-    dst->red ^= ~src->red;
+srcXor(struct RGBColor * const src, 
+       struct RGBColor * const dst) {
+    dst->red   ^= ~src->red;
     dst->green ^= ~src->green;
-    dst->blue ^= ~src->blue;
+    dst->blue  ^= ~src->blue;
 }
 
 
 
 static void 
-srcBic(struct RGBColour * const src, 
-       struct RGBColour * const dst) {
+srcBic(struct RGBColor * const src, 
+       struct RGBColor * const dst) {
     if (rgb_is_black(src))
         *dst = background;
 }
@@ -714,8 +715,8 @@ srcBic(struct RGBColour * const src,
 
 
 static void 
-notSrcCopy(struct RGBColour * const src, 
-           struct RGBColour * const dst) {
+notSrcCopy(struct RGBColor * const src, 
+           struct RGBColor * const dst) {
     if (rgb_is_white(src))
         *dst = foreground;
     else if (rgb_is_black(src))
@@ -725,8 +726,8 @@ notSrcCopy(struct RGBColour * const src,
 
 
 static void 
-notSrcOr(struct RGBColour * const src, 
-         struct RGBColour * const dst) {
+notSrcOr(struct RGBColor * const src, 
+         struct RGBColor * const dst) {
     if (rgb_is_white(src))
         *dst = foreground;
 }
@@ -734,8 +735,8 @@ notSrcOr(struct RGBColour * const src,
 
 
 static void 
-notSrcBic(struct RGBColour * const src, 
-          struct RGBColour * const dst) {
+notSrcBic(struct RGBColor * const src, 
+          struct RGBColor * const dst) {
     if (rgb_is_white(src))
         *dst = background;
 }
@@ -743,8 +744,8 @@ notSrcBic(struct RGBColour * const src,
 
 
 static void 
-notSrcXor(struct RGBColour * const src, 
-          struct RGBColour * const dst) {
+notSrcXor(struct RGBColor * const src, 
+          struct RGBColor * const dst) {
     dst->red ^= src->red;
     dst->green ^= src->green;
     dst->blue ^= src->blue;
@@ -753,8 +754,8 @@ notSrcXor(struct RGBColour * const src,
 
 
 static void 
-addOver(struct RGBColour * const src, 
-        struct RGBColour * const dst) {
+addOver(struct RGBColor * const src, 
+        struct RGBColor * const dst) {
     dst->red += src->red;
     dst->green += src->green;
     dst->blue += src->blue;
@@ -763,20 +764,20 @@ addOver(struct RGBColour * const src,
 
 
 static void 
-addPin(struct RGBColour * const src, 
-       struct RGBColour * const dst) {
-    if ((long)dst->red + (long)src->red > (long)op_colour.red)
-        dst->red = op_colour.red;
+addPin(struct RGBColor * const src, 
+       struct RGBColor * const dst) {
+    if ((long)dst->red + (long)src->red > (long)op_color.red)
+        dst->red = op_color.red;
     else
         dst->red = dst->red + src->red;
 
-    if ((long)dst->green + (long)src->green > (long)op_colour.green)
-        dst->green = op_colour.green;
+    if ((long)dst->green + (long)src->green > (long)op_color.green)
+        dst->green = op_color.green;
     else
         dst->green = dst->green + src->green;
 
-    if ((long)dst->blue + (long)src->blue > (long)op_colour.blue)
-        dst->blue = op_colour.blue;
+    if ((long)dst->blue + (long)src->blue > (long)op_color.blue)
+        dst->blue = op_color.blue;
     else
         dst->blue = dst->blue + src->blue;
 }
@@ -784,8 +785,8 @@ addPin(struct RGBColour * const src,
 
 
 static void 
-subOver(struct RGBColour * const src, 
-        struct RGBColour * const dst) {
+subOver(struct RGBColor * const src, 
+        struct RGBColor * const dst) {
     dst->red -= src->red;
     dst->green -= src->green;
     dst->blue -= src->blue;
@@ -797,20 +798,20 @@ subOver(struct RGBColour * const src,
 
 
 static void 
-subPin(struct RGBColour * const src, 
-       struct RGBColour * const dst) {
-    if ((long)dst->red - (long)src->red < (long)op_colour.red)
-        dst->red = op_colour.red;
+subPin(struct RGBColor * const src, 
+       struct RGBColor * const dst) {
+    if ((long)dst->red - (long)src->red < (long)op_color.red)
+        dst->red = op_color.red;
     else
         dst->red = dst->red - src->red;
 
-    if ((long)dst->green - (long)src->green < (long)op_colour.green)
-        dst->green = op_colour.green;
+    if ((long)dst->green - (long)src->green < (long)op_color.green)
+        dst->green = op_color.green;
     else
         dst->green = dst->green - src->green;
 
-    if ((long)dst->blue - (long)src->blue < (long)op_colour.blue)
-        dst->blue = op_colour.blue;
+    if ((long)dst->blue - (long)src->blue < (long)op_color.blue)
+        dst->blue = op_color.blue;
     else
         dst->blue = dst->blue - src->blue;
 }
@@ -818,8 +819,8 @@ subPin(struct RGBColour * const src,
 
 
 static void 
-adMax(struct RGBColour * const src, 
-      struct RGBColour * const dst) {
+adMax(struct RGBColor * const src, 
+      struct RGBColor * const dst) {
     if (src->red > dst->red) dst->red = src->red;
     if (src->green > dst->green) dst->green = src->green;
     if (src->blue > dst->blue) dst->blue = src->blue;
@@ -828,8 +829,8 @@ adMax(struct RGBColour * const src,
 
 
 static void 
-adMin(struct RGBColour * const src, 
-      struct RGBColour * const dst) {
+adMin(struct RGBColor * const src, 
+      struct RGBColor * const dst) {
     if (src->red < dst->red) dst->red = src->red;
     if (src->green < dst->green) dst->green = src->green;
     if (src->blue < dst->blue) dst->blue = src->blue;
@@ -838,11 +839,11 @@ adMin(struct RGBColour * const src,
 
 
 static void 
-blend(struct RGBColour * const src, 
-      struct RGBColour * const dst) {
+blend(struct RGBColor * const src, 
+      struct RGBColor * const dst) {
 #define blend_component(cmp)    \
-    ((long)src->cmp * (long)op_colour.cmp) / 65536 +    \
-    ((long)dst->cmp * (long)(65536 - op_colour.cmp) / 65536)
+    ((long)src->cmp * (long)op_color.cmp) / 65536 +    \
+    ((long)dst->cmp * (long)(65536 - op_color.cmp) / 65536)
 
     dst->red = blend_component(red);
     dst->green = blend_component(green);
@@ -852,8 +853,8 @@ blend(struct RGBColour * const src,
 
 
 static void 
-transparent(struct RGBColour * const src, 
-            struct RGBColour * const dst) {
+transparent(struct RGBColor * const src, 
+            struct RGBColor * const dst) {
     if (src->red != background.red || src->green != background.green ||
         src->blue != background.blue)
     {
@@ -899,21 +900,21 @@ unlink(p)
 
 
 static void
-doDiffSize(struct Rect        const clipsrc,
-           struct Rect        const clipdst,
-           int                const pixSize,
-           int                const xsize,
-           int                const ysize,
-           struct RGBColour * const ctArg,
-           int                const srcaddArg,
-           int                const dstadd,
-           int                const srcwid, 
-           transfer_func      const trf,
-           struct RGBColour * const colour_map, 
-           byte *             const srcArg,
-           word *             const reddstArg,
-           word *             const greendstArg,
-           word *             const bluedstArg
+doDiffSize(struct Rect       const clipsrc,
+           struct Rect       const clipdst,
+           int               const pixSize,
+           int               const xsize,
+           int               const ysize,
+           struct RGBColor * const ctArg,
+           int               const srcaddArg,
+           int               const dstadd,
+           int               const srcwid, 
+           transfer_func     const trf,
+           struct RGBColor * const color_map, 
+           byte *            const srcArg,
+           word *            const reddstArg,
+           word *            const greendstArg,
+           word *            const bluedstArg
 
 ) {
     FILE * pnmscalePipeP;
@@ -929,14 +930,14 @@ doDiffSize(struct Rect        const clipsrc,
     pixel * rowp;
     FILE * tempFileP;
     const char * tempFilename;
-    struct RGBColour * ct;
+    struct RGBColor * ct;
     byte * src;
     int srcadd;
     word * reddst;
     word * greendst;
     word * bluedst;
-    struct RGBColour src_c;
-    struct RGBColour dst_c;
+    struct RGBColor src_c;
+    struct RGBColor dst_c;
 
     ct = ctArg; /* initial value */
     src = srcArg; /* initial value */
@@ -972,7 +973,7 @@ doDiffSize(struct Rect        const clipsrc,
         for (i = 0; i < ysize; ++i) {
             unsigned int j;
             for (j = 0; j < xsize; ++j) {
-                ct = colour_map + *src++;
+                ct = color_map + *src++;
                 fputc(REDEPTH(ct->red, 65535L), pnmscalePipeP);
                 fputc(REDEPTH(ct->green, 65535L), pnmscalePipeP);
                 fputc(REDEPTH(ct->blue, 65535L), pnmscalePipeP);
@@ -1082,7 +1083,7 @@ blit(struct Rect *      const srcRect,
      struct Rect *      const dstRect, 
      struct Rect *      const dstBounds, 
      int                const dstwid, 
-     struct RGBColour * const colour_map, 
+     struct RGBColor *  const color_map, 
      int                const mode) {
 /* I can't tell what the result value of this function is supposed to mean,
    but I found several return statements that did not set it to anything,
@@ -1104,10 +1105,10 @@ blit(struct Rect *      const srcRect,
     int ysize;
     int srcadd;
     int dstadd;
-    struct RGBColour* ct;
+    struct RGBColor* ct;
     int pkpixsize;
     struct blit_info* bi;
-    struct RGBColour src_c, dst_c;
+    struct RGBColor src_c, dst_c;
     transfer_func trf;
 
     if (ps_text)
@@ -1129,7 +1130,7 @@ blit(struct Rect *      const srcRect,
         bi->srcplane = srcplane;
         bi->pixSize = pixSize;
         bi->dstRect = clipdst;
-        bi->colour_map = colour_map;
+        bi->color_map = color_map;
         bi->mode = mode;
         return(0);
     }
@@ -1167,7 +1168,7 @@ blit(struct Rect *      const srcRect,
 
     if (!rectsamesize(&clipsrc, &clipdst)) {
         doDiffSize(clipsrc, clipdst, pixSize, xsize, ysize, ct,
-                   srcadd, dstadd, srcwid, trf, colour_map, src,
+                   srcadd, dstadd, srcwid, trf, color_map, src,
                    reddst, greendst, bluedst);
         return 1;
     }
@@ -1178,7 +1179,7 @@ blit(struct Rect *      const srcRect,
         case 8:
             for (i = 0; i < ysize; ++i) {
                 for (j = 0; j < xsize; ++j) {
-                    ct = colour_map + *src++;
+                    ct = color_map + *src++;
                     *reddst++ = ct->red;
                     *greendst++ = ct->green;
                     *bluedst++ = ct->blue;
@@ -1243,7 +1244,7 @@ blit(struct Rect *      const srcRect,
             for (i = 0; i < ysize; ++i) {
                 for (j = 0; j < xsize; ++j) {
                     grab_destination();
-                    (*trf)(colour_map + *src++, &dst_c);
+                    (*trf)(color_map + *src++, &dst_c);
                     put_destination();
                 }
                 src += srcadd;
@@ -1440,7 +1441,7 @@ do_blits(void) {
         blit(&bi->srcRect, &bi->srcBounds, bi->srcwid, bi->srcplane,
              bi->pixSize,
              &bi->dstRect, &picFrame, rowlen,
-             bi->colour_map,
+             bi->color_map,
              bi->mode);
     }
 }
@@ -1520,9 +1521,9 @@ Clip(int const version) {
 
 static void
 OpColor(int const version) {
-    op_colour.red = read_word();
-    op_colour.green = read_word();
-    op_colour.blue = read_word();
+    op_color.red = read_word();
+    op_color.green = read_word();
+    op_color.blue = read_word();
 }
 
 
@@ -1567,14 +1568,14 @@ read_pixmap(struct pixMap * const p,
 
 
 
-static struct RGBColour*
-read_colour_table(void) {
+static struct RGBColor*
+read_color_table(void) {
     longword ctSeed;
     word ctFlags;
     word ctSize;
     word val;
     int i;
-    struct RGBColour* colour_table;
+    struct RGBColor* color_table;
 
     stage = "getting color table info";
 
@@ -1588,33 +1589,33 @@ read_colour_table(void) {
         pm_message("ctSize:  %d", ctSize);
     }
 
-    stage = "reading colour table";
+    stage = "reading color table";
 
-    MALLOCARRAY(colour_table, ctSize + 1);
-    if (colour_table == NULL)
-        pm_error("no memory for colour table");
+    MALLOCARRAY(color_table, ctSize + 1);
+    if (color_table == NULL)
+        pm_error("no memory for color table");
 
     for (i = 0; i <= ctSize; i++) {
         val = read_word();
-        /* The indicies in a device colour table are bogus and usually == 0.
-         * so I assume we allocate up the list of colours in order.
+        /* The indicies in a device color table are bogus and usually == 0.
+         * so I assume we allocate up the list of colors in order.
          */
         if (ctFlags & 0x8000)
             val = i;
         if (val > ctSize)
-            pm_error("pixel value greater than colour table size");
-        colour_table[val].red = read_word();
-        colour_table[val].green = read_word();
-        colour_table[val].blue = read_word();
+            pm_error("pixel value greater than color table size");
+        color_table[val].red = read_word();
+        color_table[val].green = read_word();
+        color_table[val].blue = read_word();
 
         if (verbose > 1)
             pm_message("%d: [%d,%d,%d]", val,
-                colour_table[val].red,
-                colour_table[val].green,
-                colour_table[val].blue);
+                color_table[val].red,
+                color_table[val].green,
+                color_table[val].blue);
     }
 
-    return colour_table;
+    return color_table;
 }
 
 
@@ -1842,7 +1843,7 @@ read_pattern(void) {
     word rowBytes;
     struct pixMap p;
     byte* pm;
-    struct RGBColour* ct;
+    struct RGBColor* ct;
 
     stage = "Reading a pattern";
 
@@ -1856,7 +1857,7 @@ read_pattern(void) {
     case 1:
         skip(8); /* old pattern data */
         read_pixmap(&p, &rowBytes);
-        ct = read_colour_table();
+        ct = read_color_table();
         pm = unpackbits(&p.Bounds, rowBytes, p.pixelSize);
         free(pm);
         free(ct);
@@ -1952,7 +1953,7 @@ PnMode(int const version) {
 
 
 static void 
-read_rgb(struct RGBColour * const rgb) {
+read_rgb(struct RGBColor * const rgb) {
     rgb->red = read_word();
     rgb->green = read_word();
     rgb->blue = read_word();
@@ -1985,11 +1986,11 @@ RGBBkCol(int const v) {
 static void 
 draw_pixel(int                const x, 
            int                const y, 
-           struct RGBColour * const clr, 
+           struct RGBColor * const clr, 
            transfer_func            trf) {
 
     int i;
-    struct RGBColour dst;
+    struct RGBColor dst;
 
     if (x < clip_rect.left || x >= clip_rect.right ||
         y < clip_rect.top || y >= clip_rect.bottom)
@@ -2015,7 +2016,7 @@ draw_pen_rect(struct Rect * const r) {
 
     int i;
     int x, y;
-    struct RGBColour dst;
+    struct RGBColor dst;
 
     i = PIXEL_INDEX(r->left, r->top);  /* initial value */
     
@@ -2631,7 +2632,7 @@ do_text(word const startx,
                          ++h, ++dy) {
                         int w;
                         for (w = 0; w < glyph->width; ++w) {
-                            struct RGBColour * const colorP = 
+                            struct RGBColor * const colorP = 
                                 glyph->bmap[h * glyph->width + w] ?
                                 &black : &white;
                             draw_pixel(x + w + glyph->x, dy, colorP, text_trf);
@@ -2755,7 +2756,7 @@ directBits(int const version,
 
         blit(&srcRect, &(p.Bounds), pixwidth, pm, p.pixelSize,
                  &dstRect, &picFrame, rowlen,
-                 (struct RGBColour*)0,
+                 (struct RGBColor*)0,
                  mode);
 
         free(pm);
@@ -2791,7 +2792,7 @@ do_pixmap(int  const version,
     struct pixMap p;
     word pixwidth;
     byte* pm;
-    struct RGBColour* colour_table;
+    struct RGBColor* color_table;
     struct Rect srcRect;
     struct Rect dstRect;
 
@@ -2803,7 +2804,7 @@ do_pixmap(int  const version,
         pm_message("%d x %d rectangle", pixwidth,
             p.Bounds.bottom - p.Bounds.top);
 
-    colour_table = read_colour_table();
+    color_table = read_color_table();
 
     read_rect(&srcRect);
 
@@ -2829,10 +2830,10 @@ do_pixmap(int  const version,
 
     blit(&srcRect, &(p.Bounds), pixwidth, pm, 8,
          &dstRect, &picFrame, rowlen,
-         colour_table,
+         color_table,
          mode);
 
-    free(colour_table);
+    free(color_table);
     free(pm);
 }
 
@@ -2847,7 +2848,7 @@ do_bitmap(int const version,
     struct Rect dstRect;
     word mode;
     byte* pm;
-    static struct RGBColour colour_table[] = { 
+    static struct RGBColor color_table[] = { 
         {65535L, 65535L, 65535L}, {0, 0, 0} };
 
     read_rect(&Bounds);
@@ -2866,7 +2867,7 @@ do_bitmap(int const version,
 
     blit(&srcRect, &Bounds, Bounds.right - Bounds.left, pm, 8,
          &dstRect, &picFrame, rowlen,
-         colour_table,
+         color_table,
          mode);
 
     free(pm);
@@ -3145,7 +3146,7 @@ interpret_pict(void) {
         if (opcode < 0xa2) {
             stage = optable[opcode].name;
             if (verbose) {
-                if (!strcmp(stage, "reserved"))
+                if (STREQ(stage, "reserved"))
                     pm_message("reserved opcode=0x%x", opcode);
                 else
                     pm_message("%s", stage = optable[opcode].name);
