@@ -95,7 +95,7 @@ parse_command_line(int argc, char ** argv,
         cmdline_p->input_filename = strdup(argv[1]);
     else 
         pm_error("Too many arguments.  The only argument accepted\n"
-                 "is the input file specificaton");
+                 "is the input file specification");
 
 }
 
