@@ -3,8 +3,8 @@
 ** Copyright (C) 1989 by Jef Poskanzer.
 ** Modified by Ingo Wilken (Ingo.Wilken@informatik.uni-oldenburg.de)
 **  20/Jun/93:
-**  - 24-bit support (new options -24if, -24force)
-**  - HAM8 support (well, anything from HAM3 to HAM(MAXPLANES))
+**  - 24-bit capability (new options -24if, -24force)
+**  - HAM8 capability (well, anything from HAM3 to HAM(MAXPLANES))
 **  - now writes up to 8 (16) planes (new options -maxplanes, -fixplanes)
 **  - colormap file (new option -map)
 **  - write colormap only (new option -cmaponly)
@@ -22,7 +22,7 @@
 **  23/Oct/94:
 **  - rework of mapfile handling
 **  - added RGB8 & RGBN image types
-**  - added maskplane and transparent color support
+**  - added maskplane and transparent color capability
 **  - 24-bit & direct color modified to n-bit deep ILBM
 **  - removed "-savemem" option
 **  22/Feb/95:
@@ -38,7 +38,7 @@
 **  - added IFF text chunks
 **
 **  TODO:
-**  - multipalette support (PCHG chunk) for std and HAM
+**  - multipalette capability (PCHG chunk) for std and HAM
 **
 **
 **           std   HAM  deep  cmap  RGB8  RGBN
@@ -405,7 +405,8 @@ main(argc, argv)
                 case mskHasTransparentColor:
                     break;
                 default:
-                    pm_error("masking method \"%s\" not supported yet", 
+                    pm_error("This program does not know how to handle "
+                             "masking method '%s'", 
                              mskNAME[maskmethod]);
             }
         }
@@ -724,7 +725,7 @@ main(argc, argv)
                 if( colormap ) {
                     cmapmaxval = maxval;
                     pm_message("%d colors found", colors);
-                    nPlanes = pm_maxvaltobits(colors-1);
+                    nPlanes = pm_maxvaltobits(colors);
                     if( fixplanes > nPlanes )
                         nPlanes = fixplanes;
                 }
