@@ -86,14 +86,13 @@ extern dct_data_type   **dct_data;
  *
  *===========================================================================*/
 static boolean
-ZeroMotionBetter(currentBlock, prev, by, bx, my, mx)
-    LumBlock currentBlock;
-    MpegFrame *prev;
-    int by;
-    int bx;
-    int my;
-    int mx;
-{
+ZeroMotionBetter(LumBlockConstPtr const currentBlock,
+                 MpegFrame *      const prev,
+                 int              const by,
+                 int              const bx,
+                 int              const my,
+                 int              const mx) {
+
     int	bestDiff;
     int CompareMode;
 
@@ -137,14 +136,13 @@ ZeroMotionBetter(currentBlock, prev, by, bx, my, mx)
  *
  *===========================================================================*/
 static boolean
-DoIntraCode(currentBlock, prev, by, bx, motionY, motionX)
-    LumBlock currentBlock;
-    MpegFrame *prev;
-    int by;
-    int bx;
-    int motionY;
-    int motionX;
-{
+DoIntraCode(LumBlockConstPtr const currentBlock,
+            MpegFrame *      const prev,
+            int              const by,
+            int              const bx,
+            int              const motionY,
+            int              const motionX) {
+
     int	    x, y;
     int32 sum = 0, vard = 0, varc = 0, dif;
     int32 currPixel, prevPixel;
@@ -194,12 +192,11 @@ DoIntraCode(currentBlock, prev, by, bx, motionY, motionX)
  *
  *===========================================================================*/
 static boolean
-ZeroMotionSufficient(currentBlock, prev, by, bx)
-    LumBlock currentBlock;
-    MpegFrame *prev;
-    int by;
-    int bx;
-{
+ZeroMotionSufficient(LumBlockConstPtr const currentBlock,
+                     MpegFrame *      const prev,
+                     int              const by,
+                     int              const bx) {
+
     LumBlock	motionBlock;
     register int    fy, fx;
     register int    x, y;
@@ -207,12 +204,13 @@ ZeroMotionSufficient(currentBlock, prev, by, bx)
     fy = by*DCTSIZE;
     fx = bx*DCTSIZE;
     for ( y = 0; y < 16; y++ ) {
-	for ( x = 0; x < 16; x++ ) {
-	    motionBlock[y][x] = prev->ref_y[fy+y][fx+x];
-	}
+        for ( x = 0; x < 16; x++ ) {
+            motionBlock[y][x] = prev->ref_y[fy+y][fx+x];
+        }
     }
 
-    zeroDiff = LumBlockMAD(currentBlock, motionBlock, 0x7fffffff);
+    zeroDiff = LumBlockMAD(currentBlock, (LumBlockConstPtr)motionBlock,
+                           0x7fffffff);
 
     return (zeroDiff <= 256);
 }
@@ -245,7 +243,9 @@ ComputeAndPrintPframeMAD(currentBlock, prev, by, bx, my, mbx, numBlock)
 
 static void 
 computeCurrentBlock(MpegFrame * const current, 
-                    int const y, int const x, LumBlock currentBlock) {
+                    int         const y,
+                    int         const x,
+                    LumBlock *  const currentBlockP) {
     int fy, fx;
     int iy;
 
@@ -253,7 +253,7 @@ computeCurrentBlock(MpegFrame * const current,
     for ( iy = 0; iy < 16; iy++ ) {
         int ix;
         for ( ix = 0; ix < 16; ix++ ) {
-            currentBlock[iy][ix] = 
+            (*currentBlockP)[iy][ix] = 
                 (int16)current->orig_y[fy+iy][fx+ix];
         }
     }
@@ -262,19 +262,19 @@ computeCurrentBlock(MpegFrame * const current,
 
 
 static void
-computeMotionVectors(bool        const specificsOn, 
-                     bool        const IntraPBAllowed,
-                     MpegFrame * const current, 
-                     MpegFrame * const prev,
-                     int         const mbAddress,
-                     BlockMV **  const infoP,
-                     int         const QScale, 
-                     LumBlock          currentBlock,
-                     int         const y, 
-                     int         const x,
-                     bool *      const useMotionP, 
-                     int *       const motionYP, 
-                     int *       const motionXP) {
+computeMotionVectors(bool             const specificsOn, 
+                     bool             const IntraPBAllowed,
+                     MpegFrame *      const current, 
+                     MpegFrame *      const prev,
+                     int              const mbAddress,
+                     BlockMV **       const infoP,
+                     int              const QScale, 
+                     LumBlockConstPtr const currentBlock,
+                     int              const y, 
+                     int              const x,
+                     bool *           const useMotionP, 
+                     int *            const motionYP, 
+                     int *            const motionXP) {
 
     bool useCached;
     BlockMV * info;
@@ -375,12 +375,14 @@ computeMotionAndDct(int const lastBlockY, int const lastBlockX,
             LumBlock currentBlock;
             int motionY, motionX;
             bool useMotion;
+            LumBlockConstPtr const currentBlockP =
+                (LumBlockConstPtr) currentBlock;
 
-            computeCurrentBlock(current, y, x, currentBlock);
+            computeCurrentBlock(current, y, x, &currentBlock);
 
             computeMotionVectors(specificsOn,  IntraPBAllowed,
                                  current, prev, mbAddress, infoP,
-                                 QScale, currentBlock, y, x,
+                                 QScale, currentBlockP, y, x,
                                  &useMotion, &motionY, &motionX);
 
             dct_data[y][x].useMotion = useMotion;
