@@ -30,6 +30,8 @@
  * HEADER FILES *
  *==============*/
 
+#define _BSD_SOURCE   /* Make sure strdup() is in string.h */
+
 #include <assert.h>
 #include <sys/utsname.h>
 
@@ -48,6 +50,7 @@
 #include "opts.h"
 #include "frametype.h"
 #include "input.h"
+#include "gethostname.h"
 
 #include "ppm.h"
 #include "nstring.h"
@@ -314,25 +317,6 @@ parseArgs(int     const argc,
 
 
 
-static const char *
-getHostName(void) {
-/*----------------------------------------------------------------------------
-   Return the host name of this system.
------------------------------------------------------------------------------*/
-    struct utsname utsname;
-    int rc;
-
-    rc = uname(&utsname);
-
-    if (rc < 0)
-        pm_error("Unable to find out host name.  "
-                 "uname() failed with errno %d (%s)", errno, strerror(errno));
-
-    return strdup(utsname.nodename);
-}
-
-
-
 static void
 compileTests() {
 
@@ -557,10 +541,6 @@ getUserFrameFile(void *       const handle,
     
     struct inputSource * const inputSourceP = (struct inputSource *) handle;
 
-    if (inputSourceP->stdinUsed)
-        pm_error("You cannot combine frames from Standard Input.");
-            /* Because Caller detects end of frames by EOF */
-    
     if (frameNumber >= inputSourceP->numInputFiles)
         *ifPP = NULL;
     else {
@@ -660,7 +640,7 @@ main(int argc, char **argv) {
 
     SetStatFileName("");
 
-    hostname = getHostName();
+    hostname = GetHostName();
 
     parseArgs(argc, argv, &cmdline);
 
