@@ -24,6 +24,7 @@
 */
 
 #include <string.h>
+#include <math.h>
 
 #include "ppm.h"
 #include "ppmdraw.h"
@@ -69,11 +70,11 @@ static int extend ARGS((smallint ch));
 static int sli ARGS((void));
 static int slib ARGS((void));
 static void vscale ARGS((int *px, int *py));
-static void slider ARGS((void (*slvec) ARGS((struct svector *vec, int colour)),
-                    void (*slflood) ARGS((struct spolygon *poly, int colour)) ));
+static void slider ARGS((void (*slvec) ARGS((struct svector *vec, int color)),
+                    void (*slflood) ARGS((struct spolygon *poly, int color)) ));
 static void slidefind ARGS((char *sname, int dironly, int ucasen));
-static void draw ARGS((struct svector *vec, int colour));
-static void flood ARGS((struct spolygon *poly, int colour));
+static void draw ARGS((struct svector *vec, int color));
+static void flood ARGS((struct spolygon *poly, int color));
 
 static int ixdots, iydots;	      /* Screen size in dots */
 static FILE *slfile;		      /* Slide file descriptor */
@@ -85,7 +86,7 @@ static int pixcols, pixrows;	      /* Pixel map size */
 static double uscale = -1;	      /* Uniform scale factor */
 static int sxsize = -1, sysize = -1;  /* Scale to X, Y size ? */
 
-#include "autocad.h"                  /* AutoCAD standard colour assignments */
+#include "autocad.h"                  /* AutoCAD standard color assignments */
 
 /*  Local variables  */
 
@@ -158,8 +159,8 @@ static void vscale(px, py)
 */
 
 static void slider(slvec, slflood)
-  void (*slvec) ARGS((struct svector *vec, int colour));
-  void (*slflood) ARGS((struct spolygon *poly, int colour));
+  void (*slvec) ARGS((struct svector *vec, int color));
+  void (*slflood) ARGS((struct spolygon *poly, int color));
 {
     int i, rescale;
     unsigned char ubfr[4];	      /* Utility character buffer */
@@ -174,8 +175,8 @@ static void slider(slvec, slflood)
     short btest = 0x1234;	      /* Value to test byte-reversal */
     static struct slhead slhi =       /* Master slide header sample */
         {"AutoCAD Slide\r\n\32", 86,2, 0,0, 0.0, 0};
-    int curcolour = 7;		      /* Current vector colour */
-    pixel rgbcolour;		      /* Pixel used to clear pixmap */
+    int curcolor = 7;		      /* Current vector color */
+    pixel rgbcolor;		      /* Pixel used to clear pixmap */
 
     lx = ly = 32000;
 
@@ -193,7 +194,7 @@ static void slider(slvec, slflood)
 
     /* Verify that slide format is compatible with this program. */
 
-    if (strcmp(slfrof.slh, slhi.slh) != 0) {
+    if (STREQ(slfrof.slh, slhi.slh)) {
         pm_error("this is not an AutoCAD slide file.");
     }
 
@@ -248,7 +249,7 @@ static void slider(slvec, slflood)
        will not be corrupted. */
 
     dsar = ((double) slfrof.sxdots) / slfrof.sydots;
-    if (abs(slfrof.sdsar - dsar) > 0.0001) {
+    if (fabs(slfrof.sdsar - dsar) > 0.0001) {
 	if (adjust) {
 	    ixdots = slfrof.sxdots * (slfrof.sdsar / dsar) + 0.5;
 	    iydots = slfrof.sydots;
@@ -307,10 +308,10 @@ static void slider(slvec, slflood)
     /* Allocate image buffer and clear it to black. */
 
     pixels = ppm_allocarray(pixcols = ixdots + 1, pixrows = iydots + 1);
-    PPM_ASSIGN(rgbcolour, 0, 0, 0);
+    PPM_ASSIGN(rgbcolor, 0, 0, 0);
     ppmd_filledrectangle(pixels, pixcols, pixrows, pixmaxval, 0, 0,
 	 pixcols, pixrows, PPMD_NULLDRAWPROC,
-	 (char *) &rgbcolour);
+	 (char *) &rgbcolor);
 
     if ((rescale = slfrof.sxdots != ixdots ||
 	slfrof.sydots != iydots ||
@@ -345,7 +346,7 @@ static void slider(slvec, slflood)
 		    vscale(&vec.f.x, &vec.f.y);
 		    vscale(&vec.t.x, &vec.t.y);
 		}
-		(*slvec)(&vec, curcolour);/* Draw vector on screen */
+		(*slvec)(&vec, curcolor);/* Draw vector on screen */
 		slx = vec.f.x;	      /* Save scaled point */
 		sly = vec.f.y;
 		break;
@@ -359,7 +360,7 @@ static void slider(slvec, slflood)
 		if ((int) vec.f.y < 0) { /* start or end */
 		    if (poly.npoints != 0) { /* end?  */
 			if (poly.npoints > 2 && poly.npoints < 11) {
-			    (*slflood)(&poly, curcolour);
+			    (*slflood)(&poly, curcolor);
 			} else {
                             pm_error("Bad polygon vertex count (%d)",
 			       poly.npoints);
@@ -390,13 +391,13 @@ static void slider(slvec, slflood)
 		if (rescale) {
 		    vscale(&vec.f.x, &vec.f.y);
 		}
-		(*slvec)(&vec, curcolour);/* Draw vector */
+		(*slvec)(&vec, curcolor);/* Draw vector */
 		slx = vec.f.x;	      /* Save scaled point */
 		sly = vec.f.y;
 		break;
 
-	    case 0xFF00:	      /*  Change colour  */
-		curcolour = cw & 0xFF;
+	    case 0xFF00:	      /*  Change color  */
+		curcolor = cw & 0xFF;
 		break;
 
 	    default:		      /*  Co-ordinates	*/
@@ -408,7 +409,7 @@ static void slider(slvec, slflood)
 		   vscale(&vec.f.x, &vec.f.y);
 		   vscale(&vec.t.x, &vec.t.y);
 		}
-		(*slvec)(&vec, curcolour);
+		(*slvec)(&vec, curcolor);
 		slx = vec.f.x;	      /* Save scaled point */
 		sly = vec.f.y;
 		break;
@@ -451,7 +452,7 @@ static void slidefind(sname, dironly, ucasen)
     /* Read slide library header and verify. */
 
     if ((fread(libent, 32, 1, slfile) != 1) ||
-        (strcmp((char *)libent, "AutoCAD Slide Library 1.0\015\012\32") != 0)) {
+        (!STREQ((char *)libent, "AutoCAD Slide Library 1.0\015\012\32"))) {
         pm_error("not an AutoCAD slide library file.");
     }
     pos = 32;
@@ -469,7 +470,7 @@ static void slidefind(sname, dironly, ucasen)
 	pos += 36;
 	if (dironly) {
             pm_message("  %s", libent);
-	} else if (strcmp((char *)libent, uname) == 0) {
+	} else if (STREQ((char *)libent, uname)) {
 	    long dpos = (((((libent[35] << 8) | libent[34]) << 8) |
 			     libent[33]) << 8) | libent[32];
 	    if ((slfile == stdin) || (fseek(slfile, dpos, 0) == -1)) {
@@ -484,51 +485,51 @@ static void slidefind(sname, dironly, ucasen)
     }
 }
 
-/*  DRAW  --  Draw a vector in the given AutoCAD colour.  */
+/*  DRAW  --  Draw a vector in the given AutoCAD color.  */
 
-static void draw(vec, colour)
+static void draw(vec, color)
   struct svector *vec;
-  int colour;
+  int color;
 {
-    pixel rgbcolour;
+    pixel rgbcolor;
 
     if (blither) {
-        pm_message("Vector (%d, %d) - (%d, %d)  Colour %d",
-		   vec->f.x, vec->f.y, vec->t.x, vec->t.y, colour);
+        pm_message("Vector (%d, %d) - (%d, %d)  Color %d",
+		   vec->f.x, vec->f.y, vec->t.x, vec->t.y, color);
     }
     assert(vec->f.x >= 0 && vec->f.x < pixcols);
     assert(vec->f.y >= 0 && vec->f.y < pixrows);
     assert(vec->t.x >= 0 && vec->t.x < pixcols);
     assert(vec->t.y >= 0 && vec->t.y < pixrows);
-    PPM_ASSIGN(rgbcolour,
-	       acadcol[colour][0], acadcol[colour][1], acadcol[colour][2]);
+    PPM_ASSIGN(rgbcolor,
+	       acadcol[color][0], acadcol[color][1], acadcol[color][2]);
     ppmd_line(pixels, pixcols, pixrows, pixmaxval,
 	      vec->f.x, iydots - vec->f.y, vec->t.x, iydots - vec->t.y,
 	      PPMD_NULLDRAWPROC,
-	      (char *) &rgbcolour);
+	      (char *) &rgbcolor);
 }
 
 /*  FLOOD  --  Draw a filled polygon.  */
 
-static void flood(poly, colour)
+static void flood(poly, color)
   struct spolygon *poly;
-  int colour;
+  int color;
 {
     int i;
     char *handle = ppmd_fill_init();
-    pixel rgbcolour;
+    pixel rgbcolor;
 
     if (blither) {
-        pm_message("Polygon: %d points, fill type %d, colour %d",
-		   poly->npoints, poly->fill, colour);
+        pm_message("Polygon: %d points, fill type %d, color %d",
+		   poly->npoints, poly->fill, color);
 	for (i = 0; i < poly->npoints; i++) {
            pm_message("   Point %d:  (%d, %d)", i + 1,
 		      poly->pt[i].x, poly->pt[i].y);
 	}
     }
 
-    PPM_ASSIGN(rgbcolour,
-	       acadcol[colour][0], acadcol[colour][1], acadcol[colour][2]);
+    PPM_ASSIGN(rgbcolor,
+	       acadcol[color][0], acadcol[color][1], acadcol[color][2]);
     for (i = 0; i < poly->npoints; i++) {
 	assert(poly->pt[i].x >= 0 && poly->pt[i].x < pixcols);
 	assert(poly->pt[i].y >= 0 && poly->pt[i].y < pixrows);
@@ -539,7 +540,7 @@ static void flood(poly, colour)
 		  ppmd_fill_drawproc, handle);
     }
     ppmd_fill(pixels, pixcols, pixrows, pixmaxval,
-	      handle, PPMD_NULLDRAWPROC, (char *) &rgbcolour);
+	      handle, PPMD_NULLDRAWPROC, (char *) &rgbcolor);
 }
 
 /*  Main program. */
