@@ -55,13 +55,14 @@ parseCommandLine(int argc, char ** const argv,
    Note that the file spec array we return is stored in the storage that
    was passed to us as the argv array.
 -----------------------------------------------------------------------------*/
-    optEntry option_def[50];
+    optEntry * option_def;
         /* Instructions to OptParseOptions3 on how to parse our options.
          */
     optStruct3 opt;
-
     unsigned int option_def_index;
 
+    MALLOCARRAY_NOFAIL(option_def, 100);
+
     option_def_index = 0;   /* incremented by OPTENT3 */
     OPTENT3(0,   "left",       OPT_INT,    &cmdlineP->left,     NULL,      0);
     OPTENT3(0,   "right",      OPT_INT,    &cmdlineP->right,    NULL,      0);
@@ -415,12 +416,12 @@ createRowCutter(struct pam *        const inpamP,
     MALLOCARRAY_NOFAIL(outputPointers, outpamP->width);
 
     /* Put in left padding */
-    for (col = leftcol; col < 0 && col-leftcol < outpamP->width; ++col)
+    for (col = leftcol; col < 0; ++col)
         outputPointers[col-leftcol] = blackTuple;
-
+ 
     /* Put in extracted columns */
-    for (col = MAX(leftcol, 0);
-         col <= MIN(rightcol, inpamP->width-1);
+    for (col = MAX(leftcol, 0); 
+         col <= MIN(rightcol, inpamP->width-1); 
          ++col) {
         int const outcol = col - leftcol;
 
@@ -428,18 +429,15 @@ createRowCutter(struct pam *        const inpamP,
     }
 
     /* Put in right padding */
-    for (col = MIN(rightcol, inpamP->width-1) + 1; col <= rightcol; ++col) {
-        if (col - leftcol >= 0) {
-            outputPointers[col-leftcol] = blackTuple;
-        }
-    }
-
+    for (col = MIN(rightcol, inpamP->width-1) + 1; col <= rightcol; ++col)
+        outputPointers[col-leftcol] = blackTuple;
+    
     /* Direct input pixels that are getting cut off to the discard tuple */
 
-    for (col = 0; col < MIN(leftcol, inpamP->width); ++col)
+    for (col = 0; col < leftcol; ++col)
         inputPointers[col] = discardTuple;
 
-    for (col = MAX(0, rightcol + 1); col < inpamP->width; ++col)
+    for (col = rightcol + 1; col < inpamP->width; ++col)
         inputPointers[col] = discardTuple;
 
     MALLOCVAR_NOFAIL(rowCutterP);
@@ -499,17 +497,7 @@ main(int argc, char *argv[]) {
     if (!cmdline.pad)
         rejectOutOfBounds(inpam.width, inpam.height, leftcol, rightcol, 
                           toprow, bottomrow);
-    else {
-        if (cmdline.left > cmdline.right) 
-            pm_error("You have specified a left edge (%d) that is to the right\n"
-                     "of the right edge you specified (%d)", 
-                     cmdline.left, cmdline.right);
-        
-        if (cmdline.top > cmdline.bottom) 
-            pm_error("You have specified a top edge (%d) that is below\n"
-                     "the bottom edge you specified (%d)", 
-                     cmdline.top, cmdline.bottom);
-    }
+
     if (cmdline.verbose) {
         pm_message("Image goes from Row 0, Column 0 through Row %d, Column %d",
                    inpam.height-1, inpam.width-1);
