@@ -837,7 +837,12 @@ typedef struct {
 
        Alternatively, the analogous thing for columns.
     */
-    int    nWeight;  /* Number of elements in 'Weight' */
+    unsigned int nWeight;
+        /* Number of elements in 'Weight'.  They're consecutive, starting
+           at index 0.
+        */
+    unsigned int allocWeight;
+        /* Number of allocated frames in 'Weight' */ 
     WEIGHT *Weight;
         /* The terms of the linear combination.  Has 'nWeight' elements. 
            The coefficients (weights) of each add up to unity.
@@ -880,23 +885,27 @@ typedef struct {
 
 
 static int
-appendWeight (WLIST *WList, int index, double weight) {
-    int n;
-  
-    if (weight == 0.0) 
-        return 0;
-  
-    n=WList->nWeight;
-  
-    WList->Weight = realloc(WList->Weight, sizeof(*(WList->Weight))*(n+1));
-    if (WList->Weight == NULL)
-        pm_error ("appendWeight: realloc(%d) failed", 
-                  sizeof(*(WList->Weight))*(n+1));
-  
-    WList->Weight[n].position = index;
-    WList->Weight[n].weight   = weight;
-    WList->nWeight++;
-  
+appendWeight(WLIST * const WList,
+             int     const index,
+             double  const weight) {
+/*----------------------------------------------------------------------------
+   Add a weighting of 'weight' for index 'index' to the weight list
+   'WList'.
+-----------------------------------------------------------------------------*/
+    if (weight == 0.0) {
+        /* A weight of 0 in the list is redundant, so we don't add it.
+           A weight entry says "Add W fraction of the pixel at index I,"
+           so where W is 0, it's the same as not having the entry at all.
+        */
+    } else {
+        unsigned int const n = WList->nWeight;
+
+        assert(WList->allocWeight >= n+1);
+        
+        WList->Weight[n].position = index;
+        WList->Weight[n].weight   = weight;
+        ++WList->nWeight;
+    }
     return 0;
 }
 
@@ -920,6 +929,20 @@ floatToSample(double const value,
 
 
 
+static void
+initWeightList(WLIST *      const weightListP,
+               unsigned int const maxWeights) {
+
+    weightListP->nWeight = 0;
+    weightListP->allocWeight = maxWeights;
+    MALLOCARRAY(weightListP->Weight, maxWeights);
+    if (weightListP->Weight == NULL)
+        pm_error("Out of memory allocating a %u-element weight list.",
+                 maxWeights);
+}
+
+
+
 static void
 createWeightList(unsigned int          const targetPos,
                  unsigned int          const sourceSize,
@@ -997,8 +1020,7 @@ createWeightList(unsigned int          const targetPos,
     double norm;
     unsigned int j;
 
-    weightListP->nWeight = 0;
-    weightListP->Weight = NULL;
+    initWeightList(weightListP, rightPixel - leftPixel + 1);
 
     /* calculate weights */
     norm = 0.0;  /* initial value */
@@ -1011,7 +1033,7 @@ createWeightList(unsigned int          const targetPos,
         double const regionRight  = MIN(right, (double)(j + 1));
         double const regionWidth  = regionRight - regionLeft;
         double const regionCenter = (regionRight + regionLeft) / 2;
-        double const dist = regionCenter - windowCenter;
+        double const dist         = regionCenter - windowCenter;
         double weight;
 
         weight = filter.basicFunction(filter.horizontalScaler * dist);
@@ -2114,5 +2136,5 @@ main(int argc, char **argv ) {
     pm_close(ifP);
     pm_close(stdout);
     
-    exit(0);
+    return 0;
 }
