@@ -297,7 +297,7 @@ hex_area(double sx, double sy, double hx, double hy, double d) {
 
 
 
-/* Table initialisation function - return alpha range */
+/* Table initialization function - return alpha range */
 static int 
 atfilt_setup(double alpha, double radius, double maxscale) {
     /* other function variables */
@@ -309,7 +309,7 @@ atfilt_setup(double alpha, double radius, double maxscale) {
 
     /* do setup */
     
-    if (alpha >= 0.0 && alpha < 0.5) {
+    if (alpha >= 0.0 && alpha < 1.0) {
         /* alpha trimmed mean */
         double noinmean;
             /* number of elements (out of a possible 7) used in the mean */
@@ -333,12 +333,12 @@ atfilt_setup(double alpha, double radius, double maxscale) {
             alpharange = 3;
             alphafraction = (3.0 - noinmean)/2.0;
         }
-    } else if (alpha >= 1.0 && alpha <= 2.0) {
+    } else if (alpha > 0.5) {
         /* optimal estimation - alpha controls noise variance threshold. */
         int i;
         double noinmean = 7.0;
         alpharange = 5;                 /* edge enhancement function */
-        alpha -= 1.0;                   /* normalise it to 0.0 -> 1.0 */
+        alpha -= 1.0;                   /* normalize it to 0.0 -> 1.0 */
         mmeanscale = meanscale = maxscale;      /* compute scaled hex values */
         alphafraction = 1.0/noinmean;   
             /* Set up 1:1 division lookup - not used */
@@ -381,7 +381,7 @@ atfilt_setup(double alpha, double radius, double maxscale) {
             /* horizontal offset of vertical hex centers */
         hexvoff = 3.0 * radius/sqrt(12.0); 
             /* vertical offset of vertical hex centers */
-        /* scale tables to normalise by hexagon area, and number of
+        /* scale tables to normalize by hexagon area, and number of
            hexes used in mean 
         */
         tabscale = meanscale / (radius * hexvoff);
