@@ -27,6 +27,8 @@
   package.
 *****************************************************************************/
 
+#include <assert.h>
+
 #include "pnm.h"
 #include "shhopt.h"
 #include "mallocvar.h"
@@ -126,7 +128,7 @@ parseCommandLine (int argc, char ** argv,
         pm_error("You specified a per centage > 100 for bpercent: %f",
                  cmdlineP->bpercent);
 
-    if (luminosity + colorvalue + saturation > 0)
+    if (luminosity + colorvalue + saturation > 1)
         pm_error("You can specify only one of "
                  "-luminosity, -colorvalue, and -saturation");
     else {
@@ -334,9 +336,11 @@ computeTransferFunction(xelval            const bvalue,
    xel with brightness x.  Brightness in this case means either luminosity
    or color value (and it doesn't matter to us which).
 
-   'bvalue' is the lowest brightness that should map to zero brightness;
-   'wvalue' is the highest brightness that should map to full brightness.
-   brightnesses in between should be stretched linearly.
+   'bvalue' is the highest brightness that should map to zero brightness;
+   'wvalue' is the lowest brightness that should map to full brightness.
+   brightnesses in between should be stretched linearly.  (That stretching
+   could conceivably result in more brightnesses mapping to zero and full
+   brightness, due to rounding).
 
    Define function only for values 0..maxval.
 -----------------------------------------------------------------------------*/
@@ -348,12 +352,12 @@ computeTransferFunction(xelval            const bvalue,
     if (newBrightness == NULL)
         pm_error("Unable to allocate memory for transfer function.");
 
-    /* Map the lowest brightnesses to zero */
+    /* Clip the lowest brightnesses to zero */
     if (bvalue > 0) 
-        for (i = 0; i <= bvalue-1; ++i)
+        for (i = 0; i < bvalue; ++i)
             newBrightness[i] = 0;
 
-    /* Map the middle brightnesses to 0..maxval */
+    /* Map the middle brightnesses linearly onto 0..maxval */
     {
         unsigned int const range = wvalue - bvalue;
         unsigned int val;
@@ -362,13 +366,16 @@ computeTransferFunction(xelval            const bvalue,
              newBrightness[i] = (i-bvalue)*maxval/range);
            (with proper rounding)
         */
-        for (i = bvalue, val = maxval/2; 
+        for (i = bvalue, val = range/2; 
              i <= wvalue; 
              ++i, val += maxval)
             newBrightness[i] = MIN(val / range, maxval);
-        }
 
-    /* Map the highest brightnesses to maxval */
+        assert(newBrightness[bvalue] == 0);
+        assert(newBrightness[wvalue] == maxval);
+    }
+
+    /* Clip the highest brightnesses to maxval */
     for (i = wvalue+1; i <= maxval; ++i)
         newBrightness[i] = maxval;
 
@@ -382,8 +389,17 @@ brightScaler(xel               const p,
              pixval            const maxval,
              xelval            const newBrightness[],
              enum brightMethod const brightMethod) {
+/*----------------------------------------------------------------------------
+  Return the multiple by which the brightness pixel of color 'p' (based
+  on maxval 'maxval') should be changed according to the transfer
+  function newBrightness[], using the 'brightMethod' measure of
+  brightness.
 
+  For example, if 'brightMethod' is BRIGHT_LUMINOSITY, p is has
+  luminosity 50, and newBrightness[50] is 75, we would return 1.5.
+-----------------------------------------------------------------------------*/
     xelval oldBrightness;
+    float scaler;
              
     switch (brightMethod) {
     case BRIGHT_LUMINOSITY:
@@ -396,7 +412,14 @@ brightScaler(xel               const p,
         oldBrightness = ppm_saturation(p, maxval);
         break;
     }
-    return (float)newBrightness[oldBrightness]/oldBrightness;
+    if (oldBrightness == 0) {
+        assert(newBrightness[oldBrightness] == 0);
+        /* Doesn't matter what we scale by.  zero times anything is zero. */
+        scaler = 1.0;
+    } else
+        scaler = (float)newBrightness[oldBrightness]/oldBrightness;
+
+    return scaler;
 }
             
 
@@ -467,7 +490,7 @@ main(int argc, char *argv[]) {
     computeEndValues(ifP, cols, rows, maxval, format, cmdline, 
                      &bvalue, &wvalue);
         
-    if (wvalue < bvalue)
+    if (wvalue <= bvalue)
         pm_error("The colors which become black would overlap the "
                  "colors which become white.");
     else {
@@ -500,4 +523,3 @@ main(int argc, char *argv[]) {
     pm_close(ifP);
     return 0;
 }
-
