@@ -272,7 +272,8 @@ computeColorMapFromMap(struct pam *   const mappamP,
 
 
 static void
-initFserr(struct pam * const pamP, struct fserr * const fserrP) {
+initFserr(struct pam *   const pamP,
+          struct fserr * const fserrP) {
 /*----------------------------------------------------------------------------
    Initialize the Floyd-Steinberg error vectors
 -----------------------------------------------------------------------------*/
@@ -282,18 +283,22 @@ initFserr(struct pam * const pamP, struct fserr * const fserrP) {
 
     MALLOCARRAY(fserrP->thiserr, pamP->depth);
     if (fserrP->thiserr == NULL)
-        pm_error("Out of memory allocating Floyd-Steinberg structures");
+        pm_error("Out of memory allocating Floyd-Steinberg structures "
+                 "for depth %u", pamP->depth);
     MALLOCARRAY(fserrP->nexterr, pamP->depth);
     if (fserrP->nexterr == NULL)
-        pm_error("Out of memory allocating Floyd-Steinberg structures");
+        pm_error("Out of memory allocating Floyd-Steinberg structures "
+                 "for depth %u", pamP->depth);
     
     for (plane = 0; plane < pamP->depth; ++plane) {
         MALLOCARRAY(fserrP->thiserr[plane], fserrSize);
         if (fserrP->thiserr[plane] == NULL)
-            pm_error("Out of memory allocating Floyd-Steinberg structures");
+            pm_error("Out of memory allocating Floyd-Steinberg structures "
+                     "for Plane %u, size %u", plane, fserrSize);
         MALLOCARRAY(fserrP->nexterr[plane], fserrSize);
         if (fserrP->nexterr[plane] == NULL)
-            pm_error("Out of memory allocating Floyd-Steinberg structures");
+            pm_error("Out of memory allocating Floyd-Steinberg structures "
+                     "for Plane %u, size %u", plane, fserrSize);
     }
 
     srand((int)(time(0) ^ getpid()));
@@ -763,31 +768,74 @@ copyRaster(struct pam *   const inpamP,
 
 
 
+static void
+remap(FILE * const ifP,
+      const struct pam * const outpamCommonP,
+      tupletable         const colormap, 
+      unsigned int       const colormapSize,
+      bool               const floyd,
+      enum missingMethod const missingMethod,
+      tuple              const defaultColor,
+      bool               const verbose) {
+
+    bool eof;
+    eof = FALSE;
+    while (!eof) {
+        struct pam inpam, outpam;
+        unsigned int missingCount;
+            /* Number of pixels that were not matched in the color map (where
+               missingMethod is MISSING_CLOSE, this is always zero).
+            */
+
+        pnm_readpaminit(ifP, &inpam, PAM_STRUCT_SIZE(allocation_depth));
+    
+        outpam = *outpamCommonP;
+        outpam.width  = inpam.width;
+        outpam.height = inpam.height;
+
+        pnm_writepaminit(&outpam);
+
+        /* Set up so input buffers have extra space as needed to
+           convert the input to the output depth.
+        */
+        pnm_setminallocationdepth(&inpam, outpam.depth);
+    
+        copyRaster(&inpam, &outpam, colormap, colormapSize, floyd,
+                   missingMethod, defaultColor, &missingCount);
+        
+        if (verbose)
+            pm_message("%d pixels not matched in color map", missingCount);
+        
+        pnm_nextimage(ifP, &eof);
+    }
+}
+
+
+
+
 int
 main(int argc, char * argv[] ) {
 
     struct cmdlineInfo cmdline;
-    FILE* ifp;
-    struct pam inpam, outpam;
+    FILE * ifP;
+    struct pam outpamCommon;
+        /* Describes the output images.  Width and height fields are
+           not meaningful, because different output images might have
+           different dimensions.  The rest of the information is common
+           across all output images.
+        */
     tupletable colormap;
     unsigned int colormapSize;
     tuple defaultColor;
         /* A tuple of the color that should replace any input color that is 
            not in the colormap, if we're doing MISSING_SPECIFIED.
         */
-    unsigned int missingCount;
-        /* Number of pixels that were not matched in the color map (where
-           missingMethod is MISSING_CLOSE, this is always zero).
-        */
 
     pnm_init(&argc, argv);
 
     parseCommandLine(argc, argv, &cmdline);
 
-    ifp = pm_openr(cmdline.inputFilespec);
-
-    pnm_readpaminit(ifp, &inpam, PAM_STRUCT_SIZE(allocation_depth));
-    
+    ifP = pm_openr(cmdline.inputFilespec);
     {
         FILE * mapfile;
         struct pam mappam;
@@ -800,38 +848,28 @@ main(int argc, char * argv[] ) {
         computeColorMapFromMap(&mappam, maptuples, &colormap, &colormapSize);
         pnm_freepamarray(maptuples, &mappam);
 
-        outpam = mappam; 
-        outpam.file = stdout;
-        outpam.width = inpam.width;
-        outpam.height = inpam.height;
+        outpamCommon = mappam; 
+        outpamCommon.file = stdout;
     }
 
-    defaultColor = pnm_allocpamtuple(&outpam);
-    if (cmdline.missingcolor && outpam.depth == 3) {
+    defaultColor = pnm_allocpamtuple(&outpamCommon);
+    if (cmdline.missingcolor && outpamCommon.depth == 3) {
         pixel const color = 
-            ppm_parsecolor(cmdline.missingcolor, outpam.maxval);
+            ppm_parsecolor(cmdline.missingcolor, outpamCommon.maxval);
         defaultColor[PAM_RED_PLANE] = PPM_GETR(color);
         defaultColor[PAM_GRN_PLANE] = PPM_GETG(color);
         defaultColor[PAM_BLU_PLANE] = PPM_GETB(color);
     }
-    pnm_writepaminit(&outpam);
 
-    /* Set up so input buffers have extra space as needed to convert the input
-       to the output depth.
-    */
-    pnm_setminallocationdepth(&inpam, outpam.depth);
-    
-    copyRaster(&inpam, &outpam, colormap, colormapSize, cmdline.floyd,
-               cmdline.missingMethod, defaultColor, &missingCount);
-    
-    if (cmdline.verbose)
-        pm_message("%d pixels not matched in color map", missingCount);
+    remap(ifP, &outpamCommon, colormap, colormapSize, 
+          cmdline.floyd, cmdline.missingMethod, defaultColor,
+          cmdline.verbose);
 
     pnm_freepamtuple(defaultColor);
 
     pm_close(stdout);
 
-    pm_close(ifp);
+    pm_close(ifP);
 
     return 0;
 }
