@@ -590,10 +590,9 @@ update_best(Best * best, unsigned long total, int x, int y)
  *  Print helper for the Best structure.
  */
 static void
-pr_best(Best * best)
+pr_best(Best * const best)
 {
     int i;
-    fprintf (stderr,"%p", best);
     if (best != (Best *)NULL)
     for (i = 0; i < NUM_BEST; ++i) {
         fprintf (stderr, " (%d,%d)%lu",
