@@ -242,10 +242,12 @@ get_line_dimensions(const char line[], const struct font * const font_p,
                 int full_pixels;  /* integer part of accumulated_ics */
                 accumulated_ics += intercharacter_space;
                 full_pixels = (int) accumulated_ics;
-                *bwid_p += full_pixels;
-                accumulated_ics -= full_pixels;
+                if (full_pixels > 0) {
+                    *bwid_p += full_pixels;
+                    accumulated_ics -= full_pixels;
+                }
+                lastGlyphP = glyphP;
             }
-            lastGlyphP = glyphP;
             *bwid_p += glyphP->xadd;
         }
     }
@@ -291,13 +293,13 @@ insert_character(const struct glyph * const glyph,
 static void
 insert_characters(bit **        const bits, 
                   struct text   const lp,
-                  struct font * const font_p, 
+                  struct font * const fontP, 
                   int           const topmargin, 
                   int           const leftmargin,
                   float         const intercharacter_space,
                   int           const lspace) {
 /*----------------------------------------------------------------------------
-   Put the text 'lp' into the image 'bits' using font *font_p and
+   Render the text 'lp' into the image 'bits' using font *fontP and
    putting 'intercharacter_space' pixels between characters and
    'lspace' pixels between the lines.
 -----------------------------------------------------------------------------*/
@@ -314,7 +316,7 @@ insert_characters(bit **        const bits,
                full pixels whenever we have more than one pixel. 
             */
 
-        row = topmargin + line * (font_p->maxheight + lspace);
+        row = topmargin + line * (fontP->maxheight + lspace);
         leftcol = leftmargin;
         accumulated_ics = 0.0;  /* initial value */
     
@@ -323,9 +325,9 @@ insert_characters(bit **        const bits,
                 (unsigned char)lp.textArray[line][cursor];
             struct glyph* glyph;   /* the glyph for this character */
 
-            glyph = font_p->glyph[glyphIndex];
+            glyph = fontP->glyph[glyphIndex];
             if (glyph != NULL) {
-                const int toprow = row + font_p->maxheight + font_p->y 
+                const int toprow = row + fontP->maxheight + fontP->y 
                     - glyph->height - glyph->y;
                     /* row number in image of top row in glyph */
                 
@@ -382,6 +384,7 @@ struct outputTextCursor {
 };
 
 
+
 static void
 initializeFlowedOutputLine(struct outputTextCursor * const cursorP) {
 
@@ -424,7 +427,14 @@ static void
 placeCharacterInOutput(char                      const lastch,
                        struct font *             const fontP, 
                        struct outputTextCursor * const cursorP) {
-    
+/*----------------------------------------------------------------------------
+   Place a character of text in the text array at the position indicated
+   by *cursorP, keeping track of what space this character will occupy
+   when this text array is ultimately rendered using font *fontP.
+
+   Note that while we compute how much space the character will take when
+   rendered, we don't render it.
+-----------------------------------------------------------------------------*/
     if (cursorP->text.lineCount < cursorP->text.allocatedLineCount) {
         unsigned int const glyphIndex = (unsigned char)lastch;
         if (fontP->glyph[glyphIndex]) {
@@ -434,11 +444,13 @@ placeCharacterInOutput(char                      const lastch,
                     cursorP->widthSoFar += fontP->glyph[glyphIndex]->x;
             } else {
                 /* handle extra intercharacter space (-space option) */
-                int fullPixels;  /* integer part of accumulatedIcs */
+                unsigned int fullPixels;  /* integer part of accumulatedIcs */
                 cursorP->accumulatedIcs += cursorP->intercharacterSpace;
                 fullPixels = (int) cursorP->accumulatedIcs;
-                cursorP->widthSoFar     += fullPixels;
-                cursorP->accumulatedIcs -= fullPixels;
+                if (fullPixels > 0) {
+                    cursorP->widthSoFar += fullPixels;
+                    cursorP->accumulatedIcs -= fullPixels;
+                }
             }
             cursorP->widthSoFar += fontP->glyph[glyphIndex]->xadd;
         }
@@ -461,13 +473,14 @@ placeCharacterInOutput(char                      const lastch,
 }
 
 
-static void
-flow_text(struct text    const inputText,
-          int            const width, 
-          struct font *  const fontP, 
-          float          const intercharacterSpace,
-          struct text *  const outputTextP) {
 
+static void
+flowText(struct text    const inputText,
+         int            const width, 
+         struct font *  const fontP, 
+         float          const intercharacterSpace,
+         struct text *  const outputTextP) {
+    
     unsigned int const maxLineCount = 50;
 
     unsigned int inputLine;  
@@ -493,11 +506,11 @@ flow_text(struct text    const inputText,
 
 
 static void
-truncate_text(struct text   const inputText, 
-              unsigned int  const width, 
-              struct font * const fontP, 
-              float         const intercharacterSpace,
-              struct text * const outputTextP) {
+truncateText(struct text   const inputText, 
+             unsigned int  const width, 
+             struct font * const fontP, 
+             float         const intercharacterSpace,
+             struct text * const outputTextP) {
 
     struct text truncatedText;
     int line;  /* Line number on which we are currently working */
@@ -540,8 +553,10 @@ truncate_text(struct text   const inputText,
                     int fullPixels;  /* integer part of accumulatedIcs */
                     accumulatedIcs += intercharacterSpace;
                     fullPixels = (int) intercharacterSpace;
-                    widthSoFar     += fullPixels;
-                    accumulatedIcs -= fullPixels;
+                    if (fullPixels > 0) {
+                        widthSoFar += fullPixels;
+                        accumulatedIcs -= fullPixels;
+                    }
                 }
                 widthSoFar += fontP->glyph[lastch]->xadd;
             }
@@ -559,14 +574,14 @@ truncate_text(struct text   const inputText,
 
 
 static void
-get_text(const char          cmdline_text[], 
-         struct font * const fn, 
-         struct text * const input_textP) {
+getText(const char          cmdline_text[], 
+        struct font * const fn, 
+        struct text * const input_textP) {
 
     struct text input_text;
 
     if (cmdline_text) {
-        allocTextArray(&input_text, 1, strlen(cmdline_text)*8);
+        allocTextArray(&input_text, 1, strlen(cmdline_text));
         strcpy(input_text.textArray[0], cmdline_text);
         fix_control_chars(input_text.textArray[0], fn);
         input_text.lineCount = 1;
@@ -586,9 +601,6 @@ get_text(const char          cmdline_text[],
         
         lineCount = 0;  /* initial value */
         while (fgets(buf, sizeof(buf), stdin) != NULL) {
-            if (strlen(buf)*8 + 1 >= sizeof(buf))
-                pm_error("A line of input text is longer than %u characters."
-                         "Cannot process.", (sizeof(buf)-1)/8);
             fix_control_chars(buf, fn);
             if (lineCount >= maxlines) {
                 maxlines *= 2;
@@ -642,8 +654,8 @@ main(int argc, char *argv[]) {
     int rows, cols;
     struct font* fontP;
     int vmargin, hmargin;
-    struct text input_text;
-    struct text lp;
+    struct text inputText;
+    struct text formattedText;
     int maxwidth;
         /* width in pixels of the longest line of text in the image */
     int maxleftb;
@@ -666,13 +678,13 @@ main(int argc, char *argv[]) {
         exit(0);
     }
 
-    get_text(cmdline.text, fontP, &input_text);
+    getText(cmdline.text, fontP, &inputText);
     
     if (cmdline.nomargins) {
         vmargin = 0;
         hmargin = 0;
     } else {
-        if (input_text.lineCount == 1) {
+        if (inputText.lineCount == 1) {
             vmargin = fontP->maxheight / 2;
             hmargin = fontP->maxwidth;
         } else {
@@ -683,40 +695,37 @@ main(int argc, char *argv[]) {
 
     if (cmdline.width > 0) {
         /* Flow or truncate lines to meet user's width request */
-        if (input_text.lineCount == 1) 
-            flow_text(input_text, cmdline.width, fontP, cmdline.space, &lp);
+        if (inputText.lineCount == 1) 
+            flowText(inputText, cmdline.width, fontP, cmdline.space,
+                     &formattedText);
         else
-            truncate_text(input_text, cmdline.width, fontP, cmdline.space, 
-                          &lp);
-        freeTextArray(input_text);
+            truncateText(inputText, cmdline.width, fontP, cmdline.space,
+                         &formattedText);
+        freeTextArray(inputText);
     } else
-        lp = input_text;
+        formattedText = inputText;
     
     rows = 2 * vmargin + 
-        lp.lineCount * fontP->maxheight + 
-        (lp.lineCount-1) * cmdline.lspace;
+        formattedText.lineCount * fontP->maxheight + 
+        (formattedText.lineCount-1) * cmdline.lspace;
 
-    compute_image_width(lp, fontP, cmdline.space, &maxwidth, &maxleftb);
+    compute_image_width(formattedText, fontP, cmdline.space,
+                        &maxwidth, &maxleftb);
 
     cols = 2 * hmargin + maxwidth;
-
-    if (cols == 0 || rows == 0)
-        pm_error("Input is all whitespace and/or non-renderable characters.  "
-                 "No output.");
-
     bits = pbm_allocarray(cols, rows);
 
     /* Fill background with white */
     fill_rect(bits, 0, 0, rows, cols, PBM_WHITE);
 
     /* Put the text in  */
-    insert_characters(bits, lp, fontP, vmargin, hmargin + maxleftb, 
+    insert_characters(bits, formattedText, fontP, vmargin, hmargin + maxleftb, 
                       cmdline.space, cmdline.lspace);
 
     /* All done. */
     pbm_writepbm(stdout, bits, cols, rows, 0);
 
-    freeTextArray(lp);
+    freeTextArray(formattedText);
     pm_close(stdout);
 
     return 0;
