@@ -101,7 +101,7 @@ static bool hourspec = FALSE;      /* No hour specified yet */
 static double icelevel;           /* Ice cap theshold */
 static double glaciers;           /* Glacier level */
 static int starfraction;          /* Star fraction */
-static int starcolour;            /* Star colour saturation */
+static int starcolor;            /* Star color saturation */
 
 /*  FOURN  --  Multi-dimensional fast Fourier transform
 
@@ -199,7 +199,7 @@ static void fourn(data, nn, ndim, isign)
 }
 #undef SWAP
 
-/*  INITGAUSS  --  Initialise random number generators.  As given in
+/*  INITGAUSS  --  Initialize random number generators.  As given in
            Peitgen & Saupe, page 77. */
 
 static void initgauss(seed)
@@ -308,7 +308,7 @@ initseed(void) {
          black  body  emitting  light  at a given temperature.
          The Planck radiation equation is solved directly  for
          the R, G, and B wavelengths defined for the CIE  1931
-         Standard    Colorimetric    Observer.    The   colour
+         Standard    Colorimetric    Observer.    The   color
          temperature is specified in degrees Kelvin. */
 
 static void temprgb(temp, r, g, b)
@@ -354,18 +354,18 @@ static void etoile(pix)
             v = 255;
         }
 
-        /* We make a special case for star colour  of zero in order to
+        /* We make a special case for star color  of zero in order to
            prevent  floating  point  roundoff  which  would  otherwise
-           result  in  more  than  256 star colours.  We can guarantee
-           that if you specify no star colour, you never get more than
+           result  in  more  than  256 star colors.  We can guarantee
+           that if you specify no star color, you never get more than
            256 shades in the image. */
 
-        if (starcolour == 0) {
+        if (starcolor == 0) {
             int vi = v;
 
             PPM_ASSIGN(*pix, vi, vi, vi);
         } else {
-            temp = 5500 + starcolour *
+            temp = 5500 + starcolor *
                 pow(1 / (1 - Cast(0, 0.9999)), StarTintExp) *
                 ((rand() & 7) ? -1 : 1);
             /* Constrain temperature to a reasonable value: >= 2600K 
@@ -474,7 +474,7 @@ createPlanetStuff(float *          const a,
             (int) (((shang * (12.0 / M_PI)) + 12 +
                     (flipped ? 12 : 0)) + 0.5) % 24, icelevel, glaciers);
         pm_message("        -stars %d -saturation %d.",
-                   starfraction, starcolour);
+                   starfraction, starcolor);
     }
 
     cp = makeCp(a, n, maxval);
@@ -578,8 +578,8 @@ makeLand(int *  const irP,
          int *  const ibP,
          double const r) {
 /*----------------------------------------------------------------------------
-  Land area.  Look up colour based on elevation from precomputed
-  colour map table.
+  Land area.  Look up color based on elevation from precomputed
+  color map table.
 -----------------------------------------------------------------------------*/
     static unsigned char pgnd[][3] = {
         {206, 205, 0}, {208, 207, 0}, {211, 208, 0},
@@ -827,7 +827,7 @@ genplanet(bool         const stars,
 
     if (stars) {
         pm_message("night: -seed %d -stars %d -saturation %d.",
-                   rseed, starfraction, starcolour);
+                   rseed, starfraction, starcolor);
         cp = NULL; 
         u = NULL; u1 = NULL;
         bxf = NULL; bxc = NULL;
@@ -1115,10 +1115,10 @@ main(int argc, char ** argv) {
             starspec = TRUE;
         } else if (pm_keymatch(argv[i], "-saturation", 3)) {
             if (starcspec) {
-                pm_error("already specified a star colour saturation");
+                pm_error("already specified a star color saturation");
             }
             i++;
-            if ((i == argc) || (sscanf(argv[i], "%d", &starcolour) != 1))
+            if ((i == argc) || (sscanf(argv[i], "%d", &starcolor) != 1))
                 pm_usage(usage);
             starcspec = TRUE;
         } else if (pm_keymatch(argv[i], "-seed", 3)) {
@@ -1176,7 +1176,7 @@ main(int argc, char ** argv) {
         starfraction = 100;
     }
     if (!starcspec) {
-        starcolour = 125;
+        starcolor = 125;
     }
 
     /* Force  screen to be at least  as wide as it is high.  Long,
