@@ -581,10 +581,8 @@ readpaminitrest(struct pam * const pamP) {
     char *rc;
     int through_header;
 
-    pamP->width = 0;
-    pamP->height = 0;
-    pamP->depth = 0;
-    pamP->maxval = 0;
+    bool widthSpec, heightSpec, depthSpec, maxvalSpec;
+
     pamP->tuple_type[0] = '\0';
 
     { 
@@ -610,14 +608,26 @@ readpaminitrest(struct pam * const pamP) {
                 process_header_line(buffer, pamP, &through_header);
         }
     }
+    if (!heightSpec)
+        pm_error("No HEIGHT header line in PAM header");
+    if (!widthSpec)
+        pm_error("No WIDTH header line in PAM header");
+    if (!depthSpec)
+        pm_error("No DEPTH header line in PAM header");
+    if (!maxvalSpec)
+        pm_error("No MAXVAL header line in PAM header");
+
     if (pamP->height == 0) 
-        pm_error("HEIGHT value is zero or unspecified in PAM header");
+        pm_error("HEIGHT value is zero in PAM header");
     if (pamP->width == 0) 
-        pm_error("WIDTH value is zero or unspecified in PAM header");
+        pm_error("WIDTH value is zero in PAM header");
     if (pamP->depth == 0) 
-        pm_error("DEPTH value is zero or unspecified in PAM header");
+        pm_error("DEPTH value is zero in PAM header");
     if (pamP->maxval == 0) 
-        pm_error("MAXVAL value is zero or unspecified in PAM header");
+        pm_error("MAXVAL value is zero in PAM header");
+    if (pamP->maxval > PAM_OVERALL_MAXVAL)
+        pm_error("MAXVAL value (%lu) in PAM header is greater than %u",
+                 pamP->maxval, PAM_OVERALL_MAXVAL);
 }
 
 
@@ -721,23 +731,24 @@ pnm_writepaminit(struct pam * const pamP) {
                  "to its 'len' member, it is only %d bytes long.", 
                  pamP->len);
 
+    if (pamP->maxval > PAM_OVERALL_MAXVAL)
+        pm_error("maxval (%lu) passed to pnm_writepaminit() "
+                 "is greater than %u", pamP->maxval, PAM_OVERALL_MAXVAL);
+
     if (pamP->len < PAM_STRUCT_SIZE(tuple_type))
         tupleType = "";
     else
         tupleType = pamP->tuple_type;
 
-    if (pamP->maxval >> 8 == 0)       pamP->bytes_per_sample = 1;
-    else if (pamP->maxval >> 16 == 0) pamP->bytes_per_sample = 2;
-    else if (pamP->maxval >> 24 == 0) pamP->bytes_per_sample = 3;
-    else                              pamP->bytes_per_sample = 4;
+    pamP->bytes_per_sample = pnm_bytespersample(pamP->maxval);
     
     switch (PAM_FORMAT_TYPE(pamP->format)) {
     case PAM_TYPE:
         fprintf(pamP->file, "P7\n");
-        fprintf(pamP->file, "WIDTH %d\n",    pamP->width);
-        fprintf(pamP->file, "HEIGHT %d\n",   pamP->height);
-        fprintf(pamP->file, "DEPTH %d\n",    pamP->depth);
-        fprintf(pamP->file, "MAXVAL %ld\n",  pamP->maxval);
+        fprintf(pamP->file, "WIDTH %u\n",   (unsigned)pamP->width);
+        fprintf(pamP->file, "HEIGHT %u\n",  (unsigned)pamP->height);
+        fprintf(pamP->file, "DEPTH %u\n",   pamP->depth);
+        fprintf(pamP->file, "MAXVAL %lu\n", pamP->maxval);
         if (!stripeq(tupleType, ""))
             fprintf(pamP->file, "TUPLTYPE %s\n", pamP->tuple_type);
         fprintf(pamP->file, "ENDHDR\n");
@@ -790,6 +801,7 @@ pnm_writepaminit(struct pam * const pamP) {
 }
 
 
+
 void
 pnm_checkpam(const struct pam *   const pamP, 
              enum pm_check_type   const check_type, 
