@@ -239,7 +239,7 @@ computehashrecoverable(struct pam *   const pamP,
     full = FALSE;  /* initial value */
     
     /* Go through the entire raster, building a hash table of
-           tuple values. 
+       tuple values. 
     */
     for (row = 0; row < pamP->height && !full; ++row) {
         int col;
@@ -295,6 +295,10 @@ computetuplefreqhash(struct pam *   const pamP,
   However, if the number of unique tuple values is greater than 'maxsize', 
   return a null return value and *sizeP undefined.
 
+  The tuple values that index the hash are scaled to a new maxval of
+  'newMaxval'.  E.g.  if the input has maxval 100 and 'newMaxval' is
+  50, and a particular tuple has sample value 50, it would be counted
+  as sample value 25 in the hash.
 -----------------------------------------------------------------------------*/
     tuplehash tuplefreqhash;
     tuple * rowbuffer;  /* malloc'ed */
@@ -495,7 +499,7 @@ pnm_computetuplefreqtable2(struct pam *   const pamP,
                            sample         const newMaxval,
                            unsigned int * const countP) {
 /*----------------------------------------------------------------------------
-   Compute the a tuple frequency table from a PAM image.  This is an
+   Compute a tuple frequency table from a PAM image.  This is an
    array that tells how many times each tuple value occurs in the
    image.
 
@@ -512,12 +516,18 @@ pnm_computetuplefreqtable2(struct pam *   const pamP,
 
    If 'maxsize' is zero, allocate exactly as much space as there are
    distinct tuple values in tupleArray[], and don't give up no matter
-   how many tuple value we find (except, of course, we abort if we
+   how many tuple values we find (except, of course, we abort if we
    can't get enough memory).
 
    Return the number of unique tuple values in tupleArray[][] as
    *countP.
 
+
+   Scale the tuple values to a new maxval of 'newMaxval' before
+   processing them.  E.g. if the input has maxval 100 and 'newMaxval'
+   is 50, and a particular tuple has sample value 50, it would be
+   listed as sample value 25 in the output table.  This makes the
+   output table smaller and the processing time less.
 -----------------------------------------------------------------------------*/
     tuplehash tuplefreqhash;
     tupletable tuplefreqtable;
