@@ -6,6 +6,9 @@
 
 /* Here are some routines internal to the pbm library. */
 
-void pbm_readpbminitrest ARGS(( FILE* file, int* colsP, int* rowsP ));
+void
+pbm_readpbminitrest(FILE * file,
+                    int  * colsP,
+                    int *  rowsP);
 
 #endif /*_LIBPBM_H_*/
