@@ -2,7 +2,7 @@
 **
 ** Font routines.
 **
-** Support for BDF fonts Copyright 1993 by George Phillips.
+** BDF font code Copyright 1993 by George Phillips.
 **
 ** Copyright (C) 1991 by Jef Poskanzer.
 **
@@ -697,7 +697,9 @@ pbm_defaultfont(const char * const name) {
 
 
 struct font*
-pbm_dissectfont(bit ** const font, int const frows, int const fcols) {
+pbm_dissectfont(bit ** const font,
+                int    const frows,
+                int    const fcols) {
     /*
     ** This routine expects a font bitmap representing the following text:
     **
