@@ -19,14 +19,34 @@
 #include <string.h>
 #include <stdio.h>
 #include <errno.h>
+
 #include "pgm.h"
 #include "libpgm.h"
 #include "pbm.h"
 #include "libpbm.h"
 #include "fileio.h"
+#include "mallocvar.h"
+
+
+gray *
+pgm_allocrow(unsigned int const cols) {
+
+    gray * grayrow;
+
+    MALLOCARRAY(grayrow, cols);
+
+    if (grayrow == NULL)
+        pm_error("Unable to allocate space for a %u-column gray row", cols);
+
+    return grayrow;
+}
+
+
 
 void 
-pgm_init(int * const argcP, char ** const argv) {
+pgm_init(int *   const argcP,
+         char ** const argv) {
+
     pbm_init( argcP, argv );
 }
 
@@ -65,9 +85,34 @@ pgm_readpgminitrest(FILE * const file,
 
 
 
+static void
+validateComputableSize(unsigned int const cols,
+                       unsigned int const rows) {
+/*----------------------------------------------------------------------------
+   Validate that the dimensions of the image are such that it can be
+   processed in typical ways on this machine without worrying about
+   overflows.  Note that in C, arithmetic is always modulus
+   arithmetic, so if your values are too big, the result is not what
+   you expect.  That failed expectation can be disastrous if you use
+   it to allocate memory.
+
+   A common operation is adding 1 or 2 to the highest row or
+   column number in the image, so we make sure that's possible.
+-----------------------------------------------------------------------------*/
+    if (cols > INT_MAX - 2)
+        pm_error("image width (%u) too large to be processed", cols);
+    if (rows > INT_MAX - 2)
+        pm_error("image height (%u) too large to be processed", rows);
+}
+
+
+
 void
-pgm_readpgminit(FILE * const file, int * const colsP, 
-                int * const rowsP, gray * const maxvalP, int * const formatP) {
+pgm_readpgminit(FILE * const file,
+                int *  const colsP, 
+                int *  const rowsP,
+                gray * const maxvalP,
+                int *  const formatP) {
 
     /* Check magic number. */
     *formatP = pm_readmagicnumber( file );
@@ -101,12 +146,14 @@ pgm_readpgminit(FILE * const file, int * const colsP,
     default:
         pm_error( "bad magic number - not a pgm or pbm file" );
     }
+    validateComputableSize(*colsP, *rowsP);
 }
 
 
 
 gray
-pgm_getrawsample(FILE * const file, gray const maxval) {
+pgm_getrawsample(FILE * const file,
+                 gray   const maxval) {
 
     if (maxval < 256) {
         /* The sample is just one byte.  Read it. */
@@ -130,39 +177,33 @@ pgm_getrawsample(FILE * const file, gray const maxval) {
 
 
 void
-pgm_readpgmrow(FILE* const file, gray* const grayrow, 
-               int const cols, gray const maxval, int const format) {
+pgm_readpgmrow(FILE * const file,
+               gray * const grayrow, 
+               int    const cols,
+               gray   const maxval,
+               int    const format) {
 
     switch (format) {
     case PGM_FORMAT: {
-        int col;
+        unsigned int col;
         for (col = 0; col < cols; ++col) {
             grayrow[col] = pm_getuint(file);
-#ifdef DEBUG
             if (grayrow[col] > maxval)
-                pm_error( "value out of bounds (%u > %u)", 
-                          grayrow[col], maxval );
-#endif /*DEBUG*/
+                pm_error("value out of bounds (%u > %u)",
+                         grayrow[col], maxval);
         }
     }
     break;
         
     case RPGM_FORMAT: {
-        int col;
-        for (col = 0; col < cols; ++col) {
-            grayrow[col] = pgm_getrawsample( file, maxval );
-#ifdef DEBUG
-            if ( grayrow[col] > maxval )
-                pm_error( "value out of bounds (%u > %u)", 
-                          grayrow[col], maxval );
-#endif /*DEBUG*/
-        }
+        unsigned int col;
+        for (col = 0; col < cols; ++col)
+            grayrow[col] = pgm_getrawsample(file, maxval);
     }
     break;
     
     case PBM_FORMAT:
-    case RPBM_FORMAT:
-    {
+    case RPBM_FORMAT: {
         bit * bitrow;
         int col;
 
@@ -181,8 +222,10 @@ pgm_readpgmrow(FILE* const file, gray* const grayrow,
 
 
 
-gray**
-pgm_readpgm(FILE * const file, int * const colsP, int * const rowsP, 
+gray **
+pgm_readpgm(FILE * const file,
+            int *  const colsP,
+            int *  const rowsP, 
             gray * const maxvalP) {
 
     gray** grays;
