@@ -9,9 +9,9 @@
 /* Here are some routines internal to the ppm library. */
 
 void
-ppm_readppminitrest (FILE *   file,
-                     int *    colsP,
-                     int*     rowsP,
-                     pixval * maxvalP);
+ppm_readppminitrest(FILE *   const file, 
+                    int *    const colsP, 
+                    int *    const rowsP, 
+                    pixval * const maxvalP);
 
 #endif /*_LIBPPM_H_*/
