@@ -26,6 +26,23 @@
 #include "pbm.h"
 #include "libpbm.h"
 #include "fileio.h"
+#include "mallocvar.h"
+
+
+pixel *
+ppm_allocrow(unsigned int const cols) {
+
+    pixel * pixelrow;
+
+    MALLOCARRAY(pixelrow, cols);
+
+    if (pixelrow == 0)
+        pm_error("Unable to allocate space for a %u-column pixel row", cols);
+
+    return pixelrow;
+}
+
+
 
 void
 ppm_init( argcP, argv )
@@ -68,12 +85,35 @@ ppm_readppminitrest(FILE *   const file,
 
 
 
+static void
+validateComputableSize(unsigned int const cols,
+                       unsigned int const rows) {
+/*----------------------------------------------------------------------------
+   Validate that the dimensions of the image are such that it can be
+   processed in typical ways on this machine without worrying about
+   overflows.  Note that in C, arithmetic is always modulus
+   arithmetic, so if your values are too big, the result is not what
+   you expect.  That failed expectation can be disastrous if you use
+   it to allocate memory.
+
+   A common operation is adding 1 or 2 to the highest row or
+   column number in the image, so we make sure that's possible.
+-----------------------------------------------------------------------------*/
+    if (cols > INT_MAX - 2)
+        pm_error("image width (%u) too large to be processed", cols);
+    if (rows > INT_MAX - 2)
+        pm_error("image height (%u) too large to be processed", rows);
+}
+
+
+
 void
 ppm_readppminit(FILE *   const fileP, 
                 int *    const colsP, 
                 int *    const rowsP, 
                 pixval * const maxvalP, 
                 int *    const formatP) {
+
     /* Check magic number. */
     *formatP = pm_readmagicnumber(fileP);
     switch (PPM_FORMAT_TYPE(*formatP)) {
@@ -93,6 +133,7 @@ ppm_readppminit(FILE *   const fileP,
 	default:
         pm_error("bad magic number - not a ppm, pgm, or pbm file");
 	}
+    validateComputableSize(*colsP, *rowsP);
 }
 
 
@@ -111,6 +152,17 @@ ppm_readppmrow(FILE*  const fileP,
             pixval const r = pm_getuint(fileP);
             pixval const g = pm_getuint(fileP);
             pixval const b = pm_getuint(fileP);
+
+            if (r > maxval)
+                pm_error("Red sample value %u is greater than maxval (%u)",
+                         r, maxval);
+            if (g > maxval)
+                pm_error("Green sample value %u is greater than maxval (%u)",
+                         g, maxval);
+            if (b > maxval)
+                pm_error("Blue sample value %u is greater than maxval (%u)",
+                         b, maxval);
+
             PPM_ASSIGN(pixelrow[col], r, g, b);
 	    }
     }
