@@ -12,6 +12,7 @@
 #define _BSD_SOURCE 1      /* Make sure strdup() is in string.h */
 #define _XOPEN_SOURCE 500  /* Make sure strdup() is in string.h */
 
+#include <assert.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
@@ -49,7 +50,9 @@ static long
 invRgbnorm(pixval       const rgb,
            pixval       const maxval,
            unsigned int const hexDigits) {
-
+/*----------------------------------------------------------------------------
+  This is the inverse of 'rgbnorm', below.
+-----------------------------------------------------------------------------*/
     long retval;
 
     switch (hexDigits) {
@@ -77,14 +80,14 @@ invRgbnorm(pixval       const rgb,
 static pixval
 rgbnorm(long         const rgb, 
         pixval       const maxval, 
-        unsigned int const hexDigits, 
+        unsigned int const hexDigitCount, 
         bool         const closeOk,
         const char * const colorname) {
 /*----------------------------------------------------------------------------
-   Normalize the color (r, g, or b) value 'rgb', which was specified with
-   'hexDigits' digits, to a maxval of 'maxval'.  If the number of digits isn't
-   valid, issue an error message and identify the complete color 
-   color specification in error as 'colorname'.
+   Normalize the color (r, g, or b) value 'rgb', which was specified
+   with 'hexDigitCount' digits, to a maxval of 'maxval'.  If the
+   number of digits isn't valid, issue an error message and identify
+   the complete color color specification in error as 'colorname'.
 
    For example, if the user says 0ff/000/000 and the maxval is 100,
    then rgb is 0xff, n is 3, and our result is 
@@ -93,7 +96,9 @@ rgbnorm(long         const rgb,
 -----------------------------------------------------------------------------*/
     pixval retval;
 
-    switch (hexDigits) {
+    assert(hexDigitCount > 0);
+
+    switch (hexDigitCount) {
     case 1:
         retval = (pixval)((double) rgb * maxval / 15 + 0.5);
         break;
@@ -110,11 +115,14 @@ rgbnorm(long         const rgb,
         pm_error("color specifier '%s' has too many digits", colorname);
     }
 
-    if (!closeOk && invRgbnorm(retval, maxval, hexDigits) != rgb)
-        pm_message("WARNING: Component 0x%lx of color '%s' "
-                   "cannot be represented with maxval %u", 
-                   rgb, colorname, maxval);
-
+    if (!closeOk) {
+        long const newrgb = invRgbnorm(retval, maxval, hexDigitCount);
+        if (newrgb != rgb)
+            pm_message("WARNING: Component 0x%lx of color '%s' "
+                       "cannot be represented precisely with maxval %u.  "
+                       "Approximating as %u.",
+                       rgb, colorname, maxval, retval);
+    }
     return retval;
 }
 
@@ -156,8 +164,8 @@ parseNewHexX11(const char       colorname[],
 
 
 static void
-parseNewDecX11(const char       colorname[], 
-               long       const maxval,
+parseNewDecX11(char       const colorname[], 
+               pixval     const maxval,
                bool       const closeOk,
                pixel *    const colorP) {
 
@@ -181,7 +189,9 @@ parseNewDecX11(const char       colorname[],
             fabs((double)gNorm/maxval - fg) > epsilon ||
             fabs((double)bNorm/maxval - fb) > epsilon)
             pm_message("WARNING: Color '%s' cannot be represented "
-                       "precisely with maxval %lu", colorname, maxval);
+                       "precisely with maxval %u.  "
+                       "Approximating as (%u,%u,%u).",
+                       colorname, maxval, rNorm, gNorm, bNorm);
     }
     PPM_ASSIGN(*colorP, rNorm, gNorm, bNorm);
 }
@@ -285,7 +295,9 @@ parseOldX11Dec(const char       colorname[],
             fabs((float)gNorm/maxval - fg) > epsilon ||
             fabs((float)bNorm/maxval - fb) > epsilon)
             pm_message("WARNING: Color '%s' cannot be represented "
-                       "precisely with maxval %u", colorname, maxval);
+                       "precisely with maxval %u.  "
+                       "Approximating as (%u,%u,%u).",
+                       colorname, maxval, rNorm, gNorm, bNorm);
     }
     PPM_ASSIGN(*colorP, rNorm, gNorm, bNorm);
 }
@@ -637,14 +649,33 @@ ppm_hsv_from_color(pixel  const color,
 
     double const epsilon = 1e-5;
 
-    double const R = (double)(PPM_GETR(color) + maxval - 1) / maxval;
-    double const G = (double)(PPM_GETG(color) + maxval - 1) / maxval;
-    double const B = (double)(PPM_GETB(color) + maxval - 1) / maxval;
+    double const R = (double)PPM_GETR(color) / maxval;
+    double const G = (double)PPM_GETG(color) / maxval;
+    double const B = (double)PPM_GETB(color) / maxval;
+
+    enum hueSector {SECTOR_RED, SECTOR_GRN, SECTOR_BLU};
+    enum hueSector hueSector;
 
     struct hsv retval;
     double range;
 
-    retval.v = MAX(R, MAX(G, B));
+    if (R >= G) {
+        if (R >= B) {
+            hueSector = SECTOR_RED;
+            retval.v = R;
+        } else {
+            hueSector = SECTOR_BLU;
+            retval.v = B;
+        }
+    } else {
+        if (G >= B) {
+            hueSector = SECTOR_GRN;
+            retval.v = G;
+        } else {
+            hueSector = SECTOR_BLU;
+            retval.v = B;
+        }
+    }
 
     range = retval.v - MIN(R, MIN(G, B));
 
@@ -663,15 +694,11 @@ ppm_hsv_from_color(pixel  const color,
 
         double angle;  /* hue angle, in range -30 - +330 */
 
-        if (R == retval.v)
-            angle = 60.0 * (cb - cg);
-        else if (G == retval.v)
-            angle = 120.0 + 60.0 * (cr - cb);
-        else if (B == retval.v)
-            angle = 240.0 + 60.0 * (cg - cr);
-        else
-            pm_error("Internal error: neither r, g, nor b is maximum");
-
+        switch(hueSector) {
+        case SECTOR_RED: angle =   0.0 + 60.0 * (cb - cg); break;
+        case SECTOR_GRN: angle = 120.0 + 60.0 * (cr - cb); break;
+        case SECTOR_BLU: angle = 240.0 + 60.0 * (cg - cr); break;
+        }
         retval.h = angle >= 0.0 ? angle : 360 + angle;
     }
 
