@@ -17,6 +17,10 @@ extern "C" {
 #endif
 
 typedef unsigned long sample;
+    /* Regardless of the capacity of "unsigned long", a sample is always
+       less than 1 << 16.  This is essential for some code to avoid
+       arithmetic overflows.
+    */
 
 struct pam {
 /* This structure describes an open PAM image file.  It consists
@@ -133,7 +137,7 @@ typedef sample *tuple;
        of the image (see pam.depth above).
     */
 
-#define PAM_OVERALL_MAXVAL ULONG_MAX
+#define PAM_OVERALL_MAXVAL 65535
 
 /* Note: xv uses the same "P7" signature for its thumbnail images (it
    started using it years before PAM and unbeknownst to the designer
@@ -286,13 +290,17 @@ void
 pnm_freerowimage(unsigned char * const rowimage);
 
 void 
-pnm_readpaminit(FILE *file, struct pam * const pamP, const int size);
+pnm_readpaminit(FILE *       const file, 
+                struct pam * const pamP, 
+                int          const size);
 
 void 
 pnm_readpamrow(const struct pam * const pamP, tuple* const tuplerow);
 
-tuple** 
-pnm_readpam(FILE *file, struct pam * const pamP, const int size);
+tuple ** 
+pnm_readpam(FILE *       const file, 
+            struct pam * const pamP, 
+            int          const size);
 
 void 
 pnm_writepaminit(struct pam * const pamP);
@@ -438,6 +446,9 @@ pnm_YCbCr_to_rgbtuple(const struct pam * const pamP,
                       double             const Cr,
                       int *              const overflowP);
 
+#define pnm_rgbtupleisgray(tuple) \
+    ((tuple)[PAM_RED_PLANE] == (tuple)[PAM_GRN_PLANE] && \
+     (tuple)[PAM_RED_PLANE] == (tuple)[PAM_BLU_PLANE])
 
 /*----------------------------------------------------------------------------
    These are meant for passing to pm_system() as Standard Input feeder
