@@ -886,7 +886,11 @@ int vsnprintfN(char *str, size_t str_m, const char *fmt, va_list ap) {
     return portable_vsnprintf(str, str_m, fmt, ap);
 }
 
-int snprintfN(char * dest, size_t const str_m, const char * const fmt, ...) {
+int
+snprintfN(char *       const dest,
+          size_t       const str_m,
+          const char * const fmt,
+          ...) {
 
     va_list ap;
     va_start(ap, fmt);
