@@ -81,7 +81,11 @@ extern "C" {
    strfree() is strictly a Netpbm invention, to allow proper type checking
    when freeing storage allocated by the Netpbm asprintfN().  */
 
-int snprintfN(char *, size_t, const char *, /*args*/ ...)
+int
+snprintfN(char *       const dest,
+          size_t       const str_m,
+          const char * const fmt,
+          ...)
 #ifdef __GNUC__
   __attribute__ ((format (printf, 3, 4)))
 #endif
