@@ -160,6 +160,10 @@ bytesToWordint(wordintBytes const bytes) {
 
     wordint retval;
     unsigned int i;
+
+    /* Note that 'bytes' is a pointer, due to C array degeneration.
+       That means sizeof(bytes) isn't what you think it is.
+    */
     
     for (i = 1, retval = bytes[0]; i < sizeof(wordint); ++i) {
         retval = (retval << 8) + bytes[i];
