@@ -24,8 +24,8 @@ struct cmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
-    const char *input_filespec;  /* Filespecs of input files */
-    const char *tupletype;       /* Tuple type for output PAM */
+    const char * inputFileName;  /* Filename of input files */
+    const char * tupletype;      /* Tuple type for output PAM */
     int n_channel;
         /* The number of channels to extract.  At least 1, at most 16. */
     unsigned int channel_to_extract[MAX_CHANNELS];
@@ -33,9 +33,10 @@ struct cmdlineInfo {
 };
 
 
+
 static void
 parseCommandLine(int argc, char ** argv,
-                 struct cmdlineInfo *cmdlineP) {
+                 struct cmdlineInfo * const cmdlineP) {
 /*----------------------------------------------------------------------------
    Note that the file spec array we return is stored in the storage that
    was passed to us as the argv array.
@@ -52,7 +53,7 @@ parseCommandLine(int argc, char ** argv,
     MALLOCARRAY_NOFAIL(option_def, 100);
 
     option_def_index = 0;   /* incremented by OPTENT3 */
-    OPTENT3(0, "infile",     OPT_STRING, &cmdlineP->input_filespec, 
+    OPTENT3(0, "infile",     OPT_STRING, &cmdlineP->inputFileName, 
             &infileSpec, 0);
     OPTENT3(0, "tupletype",  OPT_STRING, &cmdlineP->tupletype, 
             &tupletypeSpec, 0);
@@ -65,7 +66,7 @@ parseCommandLine(int argc, char ** argv,
         /* Uses and sets argc, argv, and some of *cmdlineP and others. */
 
     if (!infileSpec)
-        cmdlineP->input_filespec = "-";
+        cmdlineP->inputFileName = "-";
 
     if (!tupletypeSpec)
         cmdlineP->tupletype = "";
@@ -123,7 +124,7 @@ int
 main(int argc, char *argv[]) {
 
     struct cmdlineInfo cmdline;
-    FILE* ifp;
+    FILE* ifP;
     struct pam inpam;   /* Input PAM image */
     struct pam outpam;  /* Output PAM image */
 
@@ -131,9 +132,9 @@ main(int argc, char *argv[]) {
 
     parseCommandLine(argc, argv, &cmdline);
     
-    ifp = pm_openr(cmdline.input_filespec);
+    ifP = pm_openr(cmdline.inputFileName);
 
-    pnm_readpaminit(ifp, &inpam, PAM_STRUCT_SIZE(tuple_type));
+    pnm_readpaminit(ifP, &inpam, PAM_STRUCT_SIZE(tuple_type));
 
     validate_channels(cmdline.n_channel, cmdline.channel_to_extract, 
                       inpam.depth);
