@@ -29,6 +29,7 @@
 #include "pammap.h"
 #include "shhopt.h"
 #include "mallocvar.h"
+#include "nstring.h"
 
 #define MAXCOLORS 32767u
 #define MAXDEPTH 3
@@ -624,49 +625,39 @@ mediancut(tupletable            const colorfreqtable,
 
 
 static void
-computeHistogram(struct pam *   const pamP, 
+computeHistogram(FILE *         const ifP,
+                 int *          const formatP,
+                 struct pam *   const freqPamP,
                  tupletable *   const colorfreqtableP, 
-                 unsigned int * const colorsP,
-                 sample *       const freqtableMaxvalP) {
+                 unsigned int * const colorsP) {
 /*----------------------------------------------------------------------------
-  Attempt to make a histogram of the colors in the image represented by
-  *pamP, whose file is seekable and is now positioned to the raster.
+  Make a histogram of the colors in the image in the file '*ifP'.
+  
+  Return as *freqPamP a description of the tuple values in the histogram.
+  Only the fields of *freqPamP that describe individual tuples are
+  meaningful (depth, maxval, tuple type);
 
-  If at first we don't succeed, rescale the color resolution to half
-  the present maxval and try again, repeatedly.  This will eventually
-  terminate, with maxval at worst 16, which is half of 32, and 32^3 is
-  just slightly larger than MAXCOLORS.
+  As a fringe benefit, also return the format of the input file 
+  as *formatP.
 ----------------------------------------------------------------------------*/
     tupletable colorfreqtable;
-    sample maxval;
-    pm_filepos rasterPos;
+    struct pam inpam;
 
     pm_message("making histogram...");
 
-    pm_tell2(pamP->file, &rasterPos, sizeof(rasterPos));
-
-    colorfreqtable = NULL;  /* initial value */
+    pnm_readpaminit(ifP, &inpam, PAM_STRUCT_SIZE(tuple_type));
     
-    for (maxval = pamP->maxval;
-         colorfreqtable == NULL && maxval > 0;
-         maxval /= 2)
-    {
-        pm_seek2(pamP->file, &rasterPos, sizeof(rasterPos));
-        colorfreqtable = 
-            pnm_computetuplefreqtable2(pamP, NULL, MAXCOLORS, maxval, colorsP);
-        if (colorfreqtable)
-            *freqtableMaxvalP = maxval;
-    }
+    colorfreqtable = 
+        pnm_computetuplefreqtable2(&inpam, NULL, 0, inpam.maxval, colorsP);
 
-    /* colorfreqtable is now non-null.  The "maxval > 0" in the for loop 
-       limit above is just for robustness.
-    */
+    freqPamP->size   = sizeof(*freqPamP);
+    freqPamP->len    = PAM_STRUCT_SIZE(tuple_type);
+    freqPamP->maxval = inpam.maxval;
+    freqPamP->bytes_per_sample = pnm_bytespersample(inpam.maxval);
+    freqPamP->depth  = inpam.depth;
+    STRSCPY(freqPamP->tuple_type, inpam.tuple_type);
 
-    if (*freqtableMaxvalP != pamP->maxval) 
-        pm_message("Too many colors (more than %u)!  "
-                   "scaled color resolution from maxval %lu "
-                   "to maxval %lu before choosing",
-                   MAXCOLORS, pamP->maxval, *freqtableMaxvalP);
+    *formatP = inpam.format;
 
     pm_message("%u colors found", *colorsP);
     *colorfreqtableP = colorfreqtable;
@@ -674,43 +665,39 @@ computeHistogram(struct pam *   const pamP,
 
 
 
-
 static void
-computeColorMapFromInput(struct pam *          const pamP, 
+computeColorMapFromInput(FILE *                const ifP,
                          bool                  const allColors, 
                          int                   const reqColors, 
                          enum methodForLargest const methodForLargest,
                          enum methodForRep     const methodForRep,
+                         int *                 const formatP,
+                         struct pam *          const freqPamP,
                          tupletable *          const colormapP,
-                         int *                 const colorsP,
-                         sample *              const colormapMaxvalP) {
+                         int *                 const colorsP) {
 /*----------------------------------------------------------------------------
    Produce a colormap containing the best colors to represent the
-   image represented by *pamP, whose file is seekable and now
-   positioned to the raster.  Figure it out using the median cut
+   image stream in file 'ifP'.  Figure it out using the median cut
    technique.
 
    The colormap will have 'reqcolors' or fewer colors in it, unless
    'allcolors' is true, in which case it will have all the colors that
    are in the input.
 
-   The colormap has the same maxval as the input, unless the input contains
-   more than MAXCOLORS colors.  In that case, we compute the map from a
-   maxval-reduced version of the input.  The colormap has that reduced 
-   maxval.  Note that in this case, 'allColors' does not cause the colormap
-   to have all the colors from the input; rather, it contains all the colors
-   from the input once the input's color resolution is reduced to the new
-   maxval.
+   The colormap has the same maxval as the input.
 
    Put the colormap in newly allocated storage as a tupletable 
    and return its address as *colormapP.  Return the number of colors in
    it as *colorsP and its maxval as *colormapMaxvalP.
+
+   Return the characteristics of the input file as
+   *formatP, *depthP, and *tupleTypeP.  (This information is not really
+   relevant to our colormap mission; just a fringe benefit).
 -----------------------------------------------------------------------------*/
     tupletable colorfreqtable;
     unsigned int colors;
-    sample colormapMaxval;
 
-    computeHistogram(pamP, &colorfreqtable, &colors, &colormapMaxval);
+    computeHistogram(ifP, formatP, freqPamP, &colorfreqtable, &colors);
     
     if (allColors) {
         *colormapP = colorfreqtable;
@@ -723,14 +710,13 @@ computeColorMapFromInput(struct pam *          const pamP,
             *colorsP = colors;
         } else {
             pm_message("choosing %d colors...", reqColors);
-            *colormapP = mediancut(colorfreqtable, colors, pamP->depth, 
+            *colormapP = mediancut(colorfreqtable, colors, freqPamP->depth,
                                    reqColors,
                                    methodForLargest, methodForRep);
             *colorsP = reqColors;
-            pnm_freetupletable(pamP, colorfreqtable);
+            pnm_freetupletable(freqPamP, colorfreqtable);
         }
     }
-    *colormapMaxvalP = colormapMaxval;
 }
 
 
@@ -848,14 +834,14 @@ colormapToSingleRow(struct pam * const pamP,
 
 
 static void
-colormapToImage(struct pam * const inpamP, 
-                struct pam * const outpamP, 
-                tupletable   const colormap,
-                unsigned int const colormapSize, 
-                sample       const colormapMaxval,
-                bool         const sort,
-                bool         const square,
-                tuple ***    const outputRasterP) {
+colormapToImage(int                const format,
+                const struct pam * const colormapPamP,
+                tupletable         const colormap,
+                unsigned int       const colormapSize, 
+                bool               const sort,
+                bool               const square,
+                struct pam *       const outpamP, 
+                tuple ***          const outputRasterP) {
 /*----------------------------------------------------------------------------
    Create a tuple array and pam structure for an image which includes
    one pixel of each of the colors in the colormap 'colormap'.
@@ -864,12 +850,12 @@ colormapToImage(struct pam * const inpamP,
 -----------------------------------------------------------------------------*/
     outpamP->size             = sizeof(*outpamP);
     outpamP->len              = PAM_STRUCT_SIZE(tuple_type);
-    outpamP->format           = inpamP->format;
+    outpamP->format           = format,
     outpamP->plainformat      = FALSE;
-    outpamP->depth            = inpamP->depth;
-    outpamP->maxval           = colormapMaxval;
-    outpamP->bytes_per_sample = inpamP->bytes_per_sample;
-    strcpy(outpamP->tuple_type, inpamP->tuple_type);
+    outpamP->depth            = colormapPamP->depth;
+    outpamP->maxval           = colormapPamP->maxval;
+    outpamP->bytes_per_sample = pnm_bytespersample(outpamP->maxval);
+    STRSCPY(outpamP->tuple_type, colormapPamP->tuple_type);
 
     if (sort)
         sortColormap(colormap, outpamP->depth, colormapSize);
@@ -886,12 +872,13 @@ int
 main(int argc, char * argv[] ) {
 
     struct cmdlineInfo cmdline;
-    FILE* ifP;
-    struct pam inpam, outpam;
-    tuple** colormapRaster;
+    FILE * ifP;
+    int format;
+    struct pam colormapPam;
+    struct pam outpam;
+    tuple ** colormapRaster;
     int newcolors;
     tupletable colormap;
-    sample colormapMaxval;
 
     pnm_init(&argc, argv);
 
@@ -899,21 +886,18 @@ main(int argc, char * argv[] ) {
  
     parseCommandLine(argc, argv, &cmdline);
 
-    ifP = pm_openr_seekable(cmdline.inputFilespec);
+    ifP = pm_openr(cmdline.inputFilespec);
 
-    pnm_readpaminit(ifP, &inpam, PAM_STRUCT_SIZE(tuple_type));
-    
-    computeColorMapFromInput(&inpam,
+    computeColorMapFromInput(ifP,
                              cmdline.allcolors, cmdline.newcolors, 
                              cmdline.methodForLargest, 
                              cmdline.methodForRep,
-                             &colormap, &newcolors, &colormapMaxval);
+                             &format, &colormapPam, &colormap, &newcolors);
 
     pm_close(ifP);
 
-    colormapToImage(&inpam, &outpam, colormap, newcolors, 
-                    colormapMaxval, cmdline.sort,
-                    cmdline.square, &colormapRaster);
+    colormapToImage(format, &colormapPam, colormap, newcolors, 
+                    cmdline.sort, cmdline.square, &outpam, &colormapRaster);
 
     if (cmdline.verbose)
         pm_message("Generating %u x %u image", outpam.width, outpam.height);
