@@ -19,7 +19,7 @@
 #include "nstring.h"
 #include "mallocvar.h"
 
-static struct cmdline_info {
+struct cmdline_info {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
